#!/usr/bin/php
<?php
include "/usr/local/opmon/etc/config.php";

define("ABE_TIMETOLERANCE",5);
define("ABE_LIMITROWS",20);
define("ABE_DEBUG",false);

define("ABE_LIMIT_DAY", 86400);
define("ABE_LIMIT_WEEK", 604800);
define("ABE_LIMIT_MONTH", 2592000);

function main() {

	global $argv;
	$period_2_output = "DAY";

	// check for mandatory parameters
	if (!isset($argv[1]) || !isset($argv[2]) || !isset($argv[3]))  {
		print "UNKNOWN - Undefined host, service or command\n";
		return UNKNOWN;
	}

	$host = $argv[1];
	$svc = $argv[2];
	$mode = $argv[3];

	// mount the script command line
	$a_cmd = array();
	$first = true;
	for($i=4; $i<count($argv); $i++) {

		if ($first) {
			$first = false;
			$a_cmd[] = $argv[$i];
		} else {
			$a_cmd[] = "\"".$argv[$i]."\"";
		}

	}
	$command = implode(" ",$a_cmd);

	if (ABE_DEBUG) {
		print "parsed arguments:\n";
		print "\thost = $host\n";
		print "\tservice = $svc\n";
		print "\tmode = $mode\n";
		print "\tcommand = $command\n";
		print "running command...";
	}

	// execute plugin
	$ret = exec($command, $output, $retcode);
	$ret = $output[0];

	if (ABE_DEBUG) {
		print "ok\n\n";
		print "command output = $ret\n\n";
	}

	// get the metric ids for service
	$metrics = get_metric_ids($host, $svc);
	if (empty($metrics) || $metrics === false) {
		print "$ret\n";
		return $retcode;
	}

	//print_r($metrics);

	$plugin_metrics = abe_parse_perfdata($ret,$metrics);
	if (empty($plugin_metrics) || $plugin_metrics === false) {
		if (DEBUG) {
			print "empty plugin_metrics\n";
		}
		print "$ret\n";
		return $retcode;
	}

	$metric = false;
	$plugin_first_metric = $plugin_metrics[0];
	foreach($metrics as $m) {
		if ($plugin_first_metric->metric_name == $m->metric_name) {
			$metric = $m;
			break;
		}
	}

	if ($metric == false) {
		print "$ret\n";
		exit($retcode);
	}

	if (ABE_DEBUG) {
		print "metric :";
		print_r($metric);
	}

	$a_values = array();
	switch($mode) {


	case "day":
		$a_values = get_values($metric,ABE_LIMIT_DAY);
		$period_2_output = "DAY";
		break;

	case "week":
		$a_values = get_values($metric,ABE_LIMIT_WEEK);
		$period_2_output = "WEEK";
		break;

	case "month":
		$a_values = get_values($metric,ABE_LIMIT_MONTH);
		$period_2_output = "MONTH";
		break;

	default:
		print "ABE UNKNOWN MODE - $ret\n";
		return $retcode;

	}

	// calcule the deviation
	$dev = standard_deviation($a_values);
	if ($dev === false) {
		print "$ret\n";
		return $retcode;
	}


	// calculate the average 
	$avg = abe_average($a_values);
	if ($avg === false) {
		print "$ret\n";
		return $retcode;
	}

	$bottom = $avg - $dev;
	$top = $avg + $dev;

	if (ABE_DEBUG) {
		print "______________________________________\n";
		print "summary of the analysis\n";
		print "collected_value: {$plugin_first_metric->collected_value}\n";
		print "top limit: {$top}\n";
		print "average: {$avg}\n";
		print "bottom limit: {$bottom}\n";
		print "--------------------------------------\n";
	}


	if ($plugin_first_metric->collected_value >= $bottom && $plugin_first_metric->collected_value <= $top) {
		print "NORMAL $period_2_output BASELINE - collected={$plugin_first_metric->collected_value} average={$avg} |";
		print "{$plugin_first_metric->perfdata} upper_bound=$top{$plugin_first_metric->unit};;;; lower_bound=$bottom{$plugin_first_metric->unit};;;;\n";
		return OK;
	} else {
		if ($retcode == OK)
			$retcode = WARNING;

		if ($plugin_first_metric->collected_value > $top) {
			print "TOP ABNORMAL $period_2_output BASELINE - collected={$plugin_first_metric->collected_value} limit={$top} |";
		} else {
			print "BOTTOM ABNORMAL $period_2_output BASELINE - collected={$plugin_first_metric->collected_value} limit={$bottom} |";
		}

		print "{$plugin_first_metric->perfdata} upper_bound=$top{$plugin_first_metric->unit};;;; lower_bound=$bottom{$plugin_first_metric->unit};;;;\n";
		return $retcode;
	}


}

function create_time_gaps( $period ) {

	$time = time();

	$sql = array();
	$total = ABE_LIMITROWS;
	for(;$total;$total--) {

		$time -= $period;

		$t1 = date("Y-m-d H:i:s",$time-(ABE_TIMETOLERANCE*60));
		$t2 = date("Y-m-d H:i:s",$time+(ABE_TIMETOLERANCE*60));

		$sql[] = "(entry_time >= '$t1' and entry_time <= '$t2')";

	}

	$string = implode(" or ",$sql);

	return "( $string )";


} 

function get_values($m,$period) {


	$q = "select perf_value ".
	     "from service_perf_{$m->host_id} ".
	     "where service_id = {$m->service_id} and metric_id = {$m->metric_id} and ";
	$q .= create_time_gaps($period);


	$values = array();
	$ret = do_query($q,DBPERF,OPDB_FETCH_OBJ);
	while(!$ret->EOF) {
		$values[] = $ret->fields->perf_value;
		$ret->MoveNext();
	}
	$ret->Close();


	if (ABE_DEBUG) {
		print "query to fetch data:\n";
		print "$q\n\n";
		print "returned values:\n";
		print_r($values);
	}

	return $values;

}


function abe_parse_perfdata($command_return, $metrics) {

	$a_ret = array();

	// split the plugin return from the perfdata
	list($out,$perfdata) = explode("|",$command_return);

	if (ABE_DEBUG) {
		print "debugging performance parse\n\n";
		print "output = $out\n";
		print "perfdata = $perfdata\n";
	}

	// we don't have performance data
	if (empty($perfdata)) {
		return false;
	}

	// let's split the various perfdata metrics
	$metrics = explode(" ",$perfdata);
	if (ABE_DEBUG) {
		print "encountered metrics:\n";
		print_r($metrics);
	}

	// for every metric, we split the value from the metric
	foreach($metrics as $metric) {

		if (empty($metric)) {
			continue;
		}

		// ex: [metric0]=[value0][unit];[warning];[critical];[min];[max]
		preg_match("/^(.+);[^;]*;[^;]*;[^;]*;[^;]*$/",$metric,$matches);

		// something went terribly wrong when parsing this metric
		// let's ignore it.
		if (!isset($matches[1])) {
			if (ABE_DEBUG) {
				print "invalid metric:\n";
				print_r($matches);
			}
			continue;
		}

		if (ABE_DEBUG) {
			print "separating metric from warning em critical values:\n";
			print "{$matches[1]}\n";
		}


		// matches[1] = "[metric]=[value][unit]"
		list($metric_name,$value) = explode("=",$matches[1]);
		if (empty($metric_name) || empty($value)) {
			continue;
		}

		if (ABE_DEBUG) {
			print "spliting metric name from value/unit:\n";
			print "metric = $metric_name\n";
			print "value/unit = $value\n";
		}

		$metric_name = trim($metric_name);
		$value = trim($value);

		// we need to split unit from the value
		preg_match("/^([\d+\.]+)(.*)$/", $value, $matches);
		if (!isset($matches[1])) {
			continue;
		}

		$m = new StdClass();
		$m->metric_name = $metric_name;
		$m->collected_value = $matches[1];
		$m->unit = $matches[2];
		$m->perfdata = $perfdata;
		$a_ret[] = $m;

	}

	if (empty($a_ret)) {
		return false;
	} else {
		return $a_ret;
	}
	
}

function get_metric_ids($h,$s) {


	$h = addslashes($h);
	$s = addslashes($s);
	
	if (ABE_DEBUG) {
		print "getting metrics for $h($s)\n";
	}

	$q = "select a.metric_id, a.metric, a.service_id, a.host_id ".
	     "from opcfg.service_metric a, opmon4.service_status b ".
	     "where a.service_id=b.service_id ".
	     "and b.service_description='$s' ".
	     "and b.host_name='$h'";


	$a_ret = array();
	$ret = do_query($q,DBOPMON);
	if ($ret->RecordCount() == 0) {

		$ret->Close();
		if (ABE_DEBUG) {
			print "there's no metrics for $h($s)\n";
		}

		return false;

	} else {
		while(!$ret->EOF) {

			$m = new StdClass();
			$m->metric_id = $ret->fields['metric_id'];
			$m->metric_name = $ret->fields['metric'];
			$m->host_id = $ret->fields['host_id'];
			$m->service_id = $ret->fields['service_id'];

			$a_ret[] = $m;
			$ret->MoveNext();
		}
		$ret->Close();
	}

	if (ABE_DEBUG) {
		print "metrics:";
		print_r($a_ret);
	}

	return $a_ret;

}


function abe_average($a_values) {

	if (count($a_values) == 0)
		return false;

	return (float) sprintf("%.2f",array_sum($a_values)/count($a_values));

} 


function standard_deviation($a_values, $b_sample = false) {


	if (count($a_values) == 0) {
		return false;
	}

	$f_mean = array_sum($a_values) / count($a_values);
	$f_variance = 0.0;
	foreach ($a_values as $i) {
		$f_variance += pow($i - $f_mean, 2);
	}
	$f_variance /= ( $b_sample ? count($a_values) - 1 : count($a_values) );
	return (float) sprintf("%.2f",sqrt($f_variance));

}


exit(main());

?>
