#!/usr/bin/php -q
<?php
define("BASEDIR","/usr/local/opmon");                                                                                                                                                                    
define("DBOPCFG","opcfg");                                                                                                                                                                               
include_once(BASEDIR."/etc/db.php");                                                                                                                                                                     
include_once(BASEDIR."/share/oplib/libphp/opdb/OPDB.php");                                                                                                                                               
include_once(BASEDIR."/share/oplib/libphp/opdb/OPDB_ResultHandler.php");                                                                                                                                 
require_once(BASEDIR."/share/oplib/libphp/opmonclasses/functions.php");                                                                                                                                  
require_once(BASEDIR."/share/oplib/libphp/opmonclasses/OtrsInterface.php");                                                                                                                              
                                                                                                                                                                                                         
if(!OtrsInterface::integrationEnabled()){                                                                                                                                                                
  print "Error: OpMon/OTRS integration not enabled.";                                                                                                                                                    
  exit;                                                                                                                                                                                                  
} 


include_once(BASEDIR."/share/oplib/libphp/opmonclasses/AlcatelLucent5520Integration.php");


$options = getopt("s:u:p:o:h",array('server:','username:','password:','olt:','help','debug'));

$p_server = $p_user = $p_pass = $p_debug = $p_olt = '';

foreach ($options as $opt => $optval){
    switch($opt){
    	case 'h':
	case 'help':
	    help();
	    exit;
	break;
	case 's':
	case 'server':
	    $p_server = $optval;    	    
	break;
	case 'u':
	case 'username':
	    $p_user = $optval;
	break;    
	case 'p':
	case 'password':
	    $p_pass = $optval;
	break;
	case 'o':
	case 'olt':
	    $p_olt = $optval;
	break;
	case 'debug':
	    $p_debug = 3;
	break;
    }
}


function help() {
$help = "
	Discover Alcatel Lucent 5520 equipments using TL1 GW
    
    Usage discover_al5520.php -s API_SERVER_URL -u USERNAME -p PASSWORD -o OLT
    ex: discover_al5520.php -s 10.1.1.1 -u ossmon -p osspass -o olt1
    
    Options:
    -s | --server	5520 gearman gw server
    -u | --user 	5520 tl1 username
    -p | --pass		5520 tl1 password
    -o | --olt		5520 tl1 olt
    
    -h | --help		This help

";
print $help."\n";
}

if (count($options) == 0 || empty($p_server) || empty($p_user) || empty($p_pass) || empty($p_olt)){
    help();    
    exit;
}


$attribute_mapping_5520_otrs = '
{"OLT": {"class": "OLT", "classID": "", "name": "name" ,"definition": 
  {"ipAddress": "IPAddress"}},
"LT": {"class": "OLT-Card Slot", "classID": "", "name": "name" ,"definition": 
  {"status": "OperationalState", "type": "Type"}},
"PON": {"class": "OLT-Card Slot-PON", "classID": "", "name": "name" ,"definition":
  {"status": "OperationalState", "LABEL": "Description"}},
"ONT": {"class": "ONT", "classID": "", "name": "SUBSLOCID" ,"definition":  
  {"status": "status", "SERNUM": "SerialNumber", "EQPTVERNUM": "VersionNumber", "SWVERACT":"ActiveSoftware"}}}';

$mapping = json_decode($attribute_mapping_5520_otrs);
$classes =  OtrsInterface::getClassList();

$integration_config = OtrsInterface::getIntegrationConfig();
$default_config = array();

$config_items = array();
$total = 0;
$start = mktime();

if ($integration_config) {
  $default_config['DeplStateID'] = ($integration_config->initial_deployment_state) ? $integration_config->initial_deployment_state : false;
  if (!$default_config['DeplStateID']){
	$default_config['DeplStateID'] = array_search('Production',OtrsInterface::getDeploymentStateList());
  }
  $default_config['InciStateID'] = ($integration_config->initial_incident_state) ? $integration_config->initial_incident_state : false;
  if (!$default_config['InciStateID']){
	$default_config['InciStateID'] = array_search('Operational',OtrsInterface::getIncidentStateList());
  }
}


$current_config_items = array();
foreach ($mapping as $name => $c) {  
  $classid = array_search($c->class,$classes);
  if ($classid){
	$c->classID = $classid;
	//$current_config_items[$c->classID] = OtrsInterface::getConfigItemResultList($c->classID);	
  }
}

$cl = new AlcatelLucent5520Integration($p_server,$p_user,$p_pass,$p_olt);
$cl->debug = $p_debug;	

$dryrun = false;
		
$data = array();

//$cl->testfile = 'data-RTRV-GW-NELIST_TNM1.txt';	
$olts = $cl->get_olts();

function find_source_id($n,$exclude) {
  global $config_items_link;
  $p = substr(strrchr($n, ":"), 1);
  $c = substr($n,0,strrpos($n,':'));     
  
  //print "$p --- $c\n";
  
  while (!in_array($c,$config_items_link) && !in_array($p,$exclude) ) {
	$p = substr(strrchr($c, ":"), 1);
	$c = substr($c,0,strrpos($c,':'));  
  }
  return array_search($c,$config_items_link);
}


foreach ($olts['OLT'] as $olt){
  print "OLT -> {$olt['objectFullName']}\n";
  if($olt['objectFullName'] != 'olt:OLTCTA3'){
  	continue;
  }

  print '--------------- OLT: '.$olt['objectFullName']."\n";
  
  $equipments = $cl->get_olts_equipments($olt['objectFullName']);    
  
  $equipments['OLT'] = array($olt);
  
  $config_items_link = array();

  $pnumber = 1;
  
  $old_elements = array();
  foreach($equipments as $hw_class => $elements) {
	print 'HWClass: '.$hw_class;	
	if (empty($mapping->$hw_class)){
	  print "\n";
	  continue;
	}
	//var_dump($elements);
	$map = $mapping->$hw_class;	
	if (!is_array($elements)){
	  $elements = array($elements);
	}
	print " - found (".count($elements).") elements\n";
	foreach ($elements as $k => $element) {
		$config = $default_config;	  		
		$config['ClassID'] = $map->classID;
		$config['Name'] = (string)$element[$map->name];	
		$version = array();		
		print $k." ---- ".$config['Name'] ."\n";		
				
		if (!isset($old_elements[$map->classID])){		   
		  $cir = OtrsInterface::getConfigItemResultList($map->classID);
		  foreach($cir as $obj){
			$current_discoverid = OtrsInterface::getConfigItemDiscoverId($obj->ConfigItemID);
			if ($current_discoverid){
		  	  $old_elements[$map->classID][$obj->ConfigItemID] = $current_discoverid;
		  	}
		  }
		}

		$current_discoverid = $element['objectFullName'];  
		$current_configitemid = array_search($current_discoverid,$old_elements[$map->classID]);
		print "-- discoverid - $current_discoverid\n";
		if ($current_configitemid){
		  print "-- ConfigItem - $current_configitemid  already exists\n";
		  $config['ConfigItemID'] = $current_configitemid;
		}
		$version['DiscoverID'] = array('Content' => $current_discoverid);		
		
		foreach($map->definition as $from_attribute => $to_attribute){
		//print "--- $from_attribute -> $to_attribute\n";
		  if (!empty($element[$from_attribute])) {
			$version[$to_attribute] = array( 'Content' => (string)$element[$from_attribute] );
		  }
		} 
		$config['Version'] = $version;
		if (!$dryrun) {
		  $config['Number'] = OtrsInterface::addConfigItemInfo($config,false);		
		} else {
		  $config['Number'] = $pnumber++;
		}
		if (!is_numeric($config['Number'])){
		  print " -- Error: ";
		  var_dump($config);
		  continue;
		}		
		//$config['ObjectFullName'] = (string)$element->objectFullName;
		//$config_items[] = $config;		
		
		//var_dump($config);
		$config_items_link[$config['Number']] = (string)$element['objectFullName'];
		$total++;
	}	
  }
  
  //var_dump($config_items_link);
  
  foreach($config_items_link as $target_id => $item){
	$source_id = find_source_id($item,array('olt:'.$olt['name'].':rack-1:shelf-1',$olt['name']));
	print "Linking $item ($target_id) --> " . $source_id ."\n";
	if ($source_id){
	  if (!$dryrun) {
		OtrsInterface::addLinkToConfigItem( $source_id, $target_id );
	  }
	}
  }

}


$end = mktime();
print "-- Total: ".$total."\n";
print "-- Elapsed time: " .($end - $start) . " seconds\n";

?>
