#!/usr/bin/php -q
<?php
define("BASEDIR","/usr/local/opmon");
include_once(BASEDIR . "/etc/db.php");
include_once(BASEDIR."/share/oplib/libphp/opdb/OPDB.php");
include_once(BASEDIR."/share/oplib/libphp/opdb/OPDB_ResultHandler.php");
require_once(BASEDIR."/share/oplib/libphp/opmonclasses/functions.php");
require_once(BASEDIR."/share/oplib/libphp/opmonclasses/OtrsInterface.php");
include_once(BASEDIR."/share/opcfg/includes/config.inc");

include_once(BASEDIR."/share/oplib/libphp/opmonclasses/AlcatelLucent5620Integration.php");


$options = getopt("s:u:p:h",array('server:','username:','password:','help','debug'));

$p_server = $p_user = $p_pass = $p_debug = '';

foreach ($options as $opt => $optval){
    switch($opt){
    	case 'h':
	case 'help':
	    help();
	    exit;
	break;
	case 's':
	case 'server':
	    $p_server = $optval;    	    
	break;
	case 'u':
	case 'username':
	    $p_user = $optval;
	break;    
	case 'p':
	case 'password':
	    $p_pass = $optval;
	break;
	case 'debug':
	    $p_debug = true;
	break;
    }
}


function help() {
$help = "
	Discover Alcatel Lucent 5620 equipments
    
    Usage discover_al5620.php -s API_SERVER_URL -u USERNAME -p PASSWORD
    ex: discover_al5620.php -s 10.1.1.1:8080 -u ossmon -p osspass
    
    Options:
    -s | --server	5620 api server and port - syntax: server:port
    -u | --user 	5620 api username
    -p | --pass		5620 api password
    
    -h | --help		This help

";
print $help."\n";
}

if (count($options) == 0 || empty($p_server) || empty($p_user) || empty($p_pass)){
    help();    
    exit;
}


$attribute_mapping_5620_otrs = '
{"equipment.Shelf": {"class": "Router", "classID": "", "name": "displayedName", "definition": 
  {"siteId": "IPAddress","manufacturerBoardNumber": "PartNumber","serialNumber": "SerialNumber"}},
"equipment.FanTray": {"class": "Router-Fan", "classID": "", "name": "name", "definition":  
  {"deviceState": "DeviceState", "operationalState": "OperationalState","speed": "Speed"}},
"equipment.CardSlot": {"class": "Router-Card Slot", "classID": "", "name": "displayedName", "definition": 
  {"administrativeState": "AdministrativeState", "operationalState": "OperationalState", "shelfType": "Type", "manufacturerBoardNumber": "PartNumber","serialNumber": "SerialNumber"}},
"equipment.DaughterCardSlot": {"class": "Router-Card Slot", "classID": "", "name": "displayedName", "definition": 
  {"administrativeState": "AdministrativeState", "operationalState": "OperationalState", "shelfType": "Type", "manufacturerBoardNumber": "PartNumber","serialNumber": "SerialNumber"}},
"equipment.FlashMemory": {"class": "Router-Card Slot-Memory", "classID": "", "name": "displayedName", "definition": 
  {"administrativeState": "AdministrativeState", "operationalState": "OperationalState", "capacity": "Capacity", "serialNumber": "SerialNumber"}},
"equipment.ControlProcessor": {"class": "Router-Card Slot-CPU", "classID": "", "name": "displayedName", "definition": 
  {"redundantStatus": "ReduntantStatus", "manufacturerBoardNumber": "PartNumber", "serialNumber": "SerialNumber"}},
"equipment.PhysicalPort": {"class": "Interface", "classID": "", "name": "displayedName", "definition": 
  {"ipAddress": "IPAddress", "macAddress": "MacAddress", "interfaceType": "InterfaceType", "actualSpeed": "InterfaceSpeed", "vlanTag": "VLANTag",
  "allowedVlan": "AllowedVLAN", "description": "Description", "label": "Label", "administrativeState": "AdminState", "operationalState": "OperState"}},
"equipment.PowerSupplyTray": {"class": "Router-Power Supply", "classID": "", "name":"hwName", "definition": 
  {"operationalState": "OperationalState","powerSupply1Status": "PowerSupplyStatus","acVoltageStatus": "ACVoltageStatus","dcVoltageStatus": "DCVoltageStatus"}}}';


if(!OtrsInterface::integrationEnabled()){
  print "Error: OpMon/OTRS integration not enabled.";
  exit;
}


$mapping = json_decode($attribute_mapping_5620_otrs);	
$classes =  OtrsInterface::getClassList();

$integration_config = OtrsInterface::getIntegrationConfig();
$default_config = array();

$config_items = array();
$total = 0;
$start = mktime();

if ($integration_config) {
  $default_config['DeplStateID'] = ($integration_config->initial_deployment_state) ? $integration_config->initial_deployment_state : false;
  if (!$default_config['DeplStateID']){
	$default_config['DeplStateID'] = array_search('Production',OtrsInterface::getDeploymentStateList());
  }
  $default_config['InciStateID'] = ($integration_config->initial_incident_state) ? $integration_config->initial_incident_state : false;
  if (!$default_config['InciStateID']){
	$default_config['InciStateID'] = array_search('Operational',OtrsInterface::getIncidentStateList());
  }
}


$current_config_items = array();
foreach ($mapping as $name => $c) {  
  $classid = array_search($c->class,$classes);
  if ($classid){
	$c->classID = $classid;
	//$current_config_items[$c->classID] = OtrsInterface::getConfigItemResultList($c->classID);	
  }
}

$cl = new AlcatelLucent5620Integration($p_server,$p_user,$p_pass);
$cl->debug = $p_debug;
//$dryrun = true;


//$object = 'network:177.124.56.133';
$routers = $cl->get_routers();

function find_source_id($n) {
  global $config_items_link;
  $p = substr(strrchr($n, ":"), 1);
  $c = substr($n,0,strrpos($n,':'));     
  while (!in_array($c,$config_items_link) && $p != 'shelf-1' ) {
	$p = substr(strrchr($c, ":"), 1);
	$c = substr($c,0,strrpos($c,':'));  
  }
  return array_search($c,$config_items_link);
}

$old_elements = array();
foreach ($routers as $router){

  print '--------------- Router: '.$router['objectFullName']."\n";
  $equipments = $cl->get_routers_equipments($router['objectFullName']);    

  $config_items_link = array();

  foreach($equipments as $hw_class => $elements) {
	print 'HWClass: '.$hw_class;	
	if (empty($mapping->$hw_class)){
	  continue;
	}
	//var_dump($elements);
	$map = $mapping->$hw_class;	
	if (!is_array($elements)){
	  $elements = array($elements);
	}
	print " - found (".count($elements).") elements\n";
	foreach ($elements as $k => $element) {
		$config = $default_config;		
		
		if (!isset($old_elements[$map->classID])){		   
		  $cir = OtrsInterface::getConfigItemResultList($map->classID);
		  foreach($cir as $obj){
			$current_discoverid = OtrsInterface::getConfigItemDiscoverId($obj->ConfigItemID);
			if (isset($current_discoverid)){
		  	  $old_elements[$map->classID][$obj->ConfigItemID] = $current_discoverid;
		  	}
		  }
		}
	  	
		$config['ClassID'] = $map->classID;
		$config['Name'] = (string)$element->{$map->name};	
		$version = array();		

		$current_discoverid = (string)$element->objectFullName;  
		$current_configitemid = array_search($current_discoverid,$old_elements[$map->classID]);
		print "-- discoverid - $current_discoverid\n";
		
		if ($current_configitemid){
		  print "-- ConfigItem - $current_configitemid  already exists\n";
		  $config['ConfigItemID'] = $current_configitemid;
		}
		$version['DiscoverID'] = array('Content' => $current_discoverid);
		
		//print $k." ---- ".$config['Name'] ."\n";		
		foreach($map->definition as $from_attribute => $to_attribute){
		//print "--- $from_attribute -> $to_attribute\n";
		  if (!empty($element->$from_attribute)) {
			$version[$to_attribute] = array( 'Content' => (string)$element->$from_attribute );
		  }
		} 
		$config['Version'] = $version;
		
		if (!$dryrun) {
		  $config['Number'] = OtrsInterface::addConfigItemInfo($config,false);		
		} else {
		  $config['Number'] = rand(0,1000) * microtime();
		}
		if (!is_numeric($config['Number'])){
		  print " -- Error: ";
		  var_dump($config);
		  continue;
		}		
		//$config['ObjectFullName'] = (string)$element->objectFullName;
		//$config_items[] = $config;		
		$config_items_link[$config['Number']] = (string)$element->objectFullName;
		$total++;
	}	
  }
  
  foreach($config_items_link as $target_id => $item){
	$source_id = find_source_id($item);
	print "Linking $item ($target_id) --> " . $source_id ."\n";
	if ($source_id){
	  if (!$dryrun) {
		OtrsInterface::addLinkToConfigItem( $source_id, $target_id );
	  }
	}
  }

}
$end = mktime();
print "-- Total: ".$total."\n";
print "-- Elapsed time: " .($end - $start) . " seconds\n";

?>
