#!/usr/bin/php
<?php

require '/usr/local/opmon/libexec/opservices/amazon/vendor/autoload.php';
use Aws\CloudWatch\CloudWatchClient;

$shortopts = "h";
$longopts = array("key:", "secret:", "region:", "warning:", "critical:", "metric:", "type:", "id:", "help", "verbose:");
$options = getopt($shortopts, $longopts);
$basename = str_replace(".php", "", basename($_SERVER[PHP_SELF]));

function main() {

        global $options;

	if ((!$options['key']) or (!$options['secret']) or (!$options['region']) or (!$options['warning']) or (!$options['critical']) or (!$options['id']) or (!$options['type'])) {
		help();
	}

	$props = array('key' => $options['key'],
                'secret' => $options['secret'],
                'region' => $options['region']
	);

	try {
		$client = CloudWatchClient::factory($props);
		$metrics = $client->listMetrics(array('Namespace' => 'AWS/EC2'));
	} catch(Exception $e) {
		die($e->getMessage());
	}
	
	$begin = time() - 600; // last 10 minutes
	$end = time(); // now

	$dimension = array('Name' => $options['type'], 'Value' => $options['id']);
	
	$att = array();
	$att['Namespace'] = "AWS/EC2";
	$att['MetricName'] = $options['metric'];
	$att['Dimensions'] = array($dimension);
	$att['Period'] = 60; // one metric at every 60 seconds
	$att['Statistics'] = array('Average');
	$att['StartTime'] = $begin;
	$att['EndTime'] = $end;
			
	try {
		$status = $client->getMetricStatistics($att);
	} catch(Exception $e) {
		die($e->getMessage());
	}

	foreach($metrics['Metrics'] as $metric) {
        	foreach($metric['Dimensions'] as $list) {
			if ($options['metric'] == "ListMetrics") {
				printf("%s=%s Metric=%s\n", $list['Name'], $list['Value'], $metric['MetricName']);
			}
			if ($list['Value'] == $options['id'] and $metric['MetricName'] == $options['metric']) {
				$exist = 1;
			}
		}
	}

	if (!$exist) {
		quit("Metric (".$options['metric'].") does not exist, use --metric=ListMetrics, for list metrics.",1);
	}

	foreach($status['Datapoints'] as $data) {
		if ($options['verbose'] > 0) {
			print sprintf("[%s] %s %s\n", $data['Timestamp'], $data['Average'], $data['Unit']);
		}
	}

	if (!$data['Average']) {
		quit("No data in the last 10 minutes",3);
	}

	if ($options['metric'] == 'CPUUtilization') {
		$perf = $status['Label']."=".$data['Average'].$data['Unit'].";".$options['warning'].";".$options['critical'].";0;100";
	}else{
		$perf = $status['Label']."=".$data['Average'].$data['Unit'].";".$options['warning'].";".$options['critical'].";0;";
	}
	$mgs = $options['type'].": ".$options['id']." - ".$status['Label'].": ".$data['Average']." ".$data['Unit'];

	$code = metric($data['Average'],$options['warning'],$options['critical']);
	quit($mgs."|".$perf."\n",$code);
}

function quit($text, $code) {

        echo $text."\n";
        exit($code);

}

function metric($value, $warn, $crit) {

        global $options;

        if ($value >= $crit) {
                return 1;
        } else if ($value >= $warn) {
                return 2;
        } else if ($value < $warn) {
                return 0;
        } else {
                quit("Unable to check.",3);
        }

}

function help() {

        global $options;
        global $basename;

	echo $basename." --key=XXXXX, --secret=XXXXX, --region=us-east-1, --warning=INTEGER, --critical=INTEGER, --metric=ListMetrics, type=InstanceId --id=I-XXXXX | --help --verbose=1\n";
	echo "--type=< InstanceId | ImageId | InstanceType>\n";
	echo "--id=< i-XXXXX | ami-XXXXX | t1.XXXXX>\n";
	echo "A region is required when using Amazon CloudWatch. Set 'region' to one of: us-east-1, us-west-1, us-west-2, eu-west-1, ap-northeast-1, ap-southeast-1, ap-southeast-2, sa-east-1, us-gov-west-1\n";
	echo "Use --metric=ListMetrics, for list all metric.\n";
	echo "One of Amazon EC2 Metrics = (CPUUtilization, NetworkIn, NetworkOut, DiskWriteOps, DiskReadBytes, DiskReadOps, DiskWriteBytes)\n";

	exit(1);
}

main();
?>
