#!/usr/bin/perl 

#check_dir.pl
#
#Description:
#--------------------------------------------------
# Agente monitora o tamanho de arquivos /var/log e seus subdiretórios
# para alarmar mediante parâmetros de warning e critical e informa o número de arquivos
# encontrados e listar eles.
# sintaxe: ./check_dir.pl -w 1048576 -c 1572864 -D "/var/log"
# OBS: Thresholds passados em KB
# ticket 1029061
#--------------------------------------------------
#
#Author:
#        Boris Vasquez (boris.vasquez@opservices.com.br)
#
#13-04-2009 : Created 
#

use strict;
use Getopt::Long;
use POSIX;
use File::Basename;

#--------------------------------------------------
# Setting environment
#-------------------------------------------------- 
$ENV{"USER"}="opuser";
$ENV{"HOME"}="/home/opuser";

#--------------------------------------------------
# Global variables
#--------------------------------------------------
our $name = basename($0, ".pl");
our $version = "1.0";
our $path = "/usr/local/opmon/libexec";
our $temp_log = "$path/$name.log";
our ($opt_help, $opt_verbose, $opt_version, $opt_warn, $opt_crit);
our ($opt_dir,@command,@command_stat);

my $metric = ""; # Generate performance data
my $perf = "$metric=value;$opt_warn;$opt_crit;;"; # Change 'value' to your '$return'
@command_stat = "/usr/bin/stat";
#$opt_dir = "/var/log";

sub main {

     getoption();
     @command = "/usr/bin/du -a $opt_dir/*";
     my @out = `@command`;
     my (@tamanho,@arquivo);
     chomp (@out);
     my $count = 0;
     foreach (@out){
	 ($tamanho[$count],$arquivo[$count]) = split (/\t/,$out[$count]);	 
	 $count++;
     }

     my @return;
     my $count5 = 0;

     foreach (@arquivo){
	 @return = `/usr/bin/stat $_`;
	 if ($return[1] =~ /directory/i){
	     splice (@arquivo,$count5,1);
	     splice (@tamanho,$count5,1);
	 }
	 $count5++;
     }



     my (@arq_crit,@arq_warn,$count_crit,$count_warn,@tam_warn,$count_array,@tam_crit);
     $count_crit = 0;
     $count_warn = 0;
     $count_array = 0;
     foreach (@tamanho){
	 if ($_ >= $opt_crit){
	     $arq_crit[$count_crit] = $arquivo[$count_array];
	     $tam_crit[$count_crit] = $_;
	     $count_crit++
	 }elsif($_ >= $opt_warn and $_ < $opt_crit){
	     $arq_warn[$count_warn] = $arquivo[$count_array];
	     $tam_warn[$count_warn] = $_;
	     $count_warn++;
	 }
	 $count_array++;
     }
#--------------------------------------------------
#      Critical
#-------------------------------------------------- 
     if ($count_crit > 0){
	 foreach (@tam_crit){
	     if ($_ >=1048576){
		 $_ = ($_/1048576);
		 $_ = sprintf("%4.2f",$_)." GB";
	     }elsif($_ >= 1024){
		 $_ = ($_/1024);
		 $_ = sprintf("%4.2f",$_)." MB";
	     }else{
		 $_ = $_." KB";
	     }
	 }
     }
#--------------------------------------------------
#      Warning
#-------------------------------------------------- 
     if ($count_warn > 0){
	 foreach (@tam_warn){
	     if ($_ >=1048576){
		 $_ = ($_/1048576);
		 $_ = sprintf("%4.2f",$_)." GB";
	     }elsif($_ >= 1024){
		 $_ = ($_/1024);
		 $_ = sprintf("%4.2f",$_)." MB";
	     }else{
		 $_ = $_." KB";
	     }
	 }
     }
#--------------------------------------------------
#      Analise
#-------------------------------------------------- 
     my @result_crit;
     my @result_warn;
     if ($count_crit > 0){
	 my $count3 = 0;
	 foreach (@arq_crit){
	     $result_crit[$count3] = "$arq_crit[$count3]"." Tamanho: "."$tam_crit[$count3]";
	     $count3++;
	 }
	 print "Critical - $count_crit arquivo(s) com tamanho inesperado: @result_crit\n";
	 exit(2);
     }
     elsif($count_warn > 0){
	 my $count4 = 0;
	 foreach (@arq_warn){
	     $result_warn[$count4] = "$arq_warn[$count4]"." Tamanho: "."$tam_warn[$count4]";
	     $count4++;
	 }
	 print "Warning - $count_warn arquivo(s) com tamanho inesperado: @result_warn\n";
	 exit(1);
     }else{
	 print "OK - Arquivos com tamanho dentro dos limites.\n";
	 exit(0);
     }


}
#--------------------------------------------------------------------------------------
sub getoption  {
     Getopt::Long::Configure('bundling');
     GetOptions(
            'V|version'               => \$opt_version,
            'c|critical=f'              => \$opt_crit,
            'h|help'                  => \$opt_help,
            'v|verbose=i'               => \$opt_verbose,
            'w|warning=f'               => \$opt_warn,
            'D|directory=s'               => \$opt_dir,
        );

     if($opt_help){

             printHelp();
              exit(1);

     }

     if($opt_version){

             print "$name.pl - '$version'\n";
             exit(1);
 
     }

     if($opt_verbose){

             $opt_verbose = 1;
     }

     else{
 
             $opt_verbose = 0;

     }

      if ((!$opt_warn) or (!$opt_crit) or (!$opt_dir)){
              printUsage();
               exit(1);
      }


}

#--------------------------------------------------------------------------------------
sub logger {

        return (0) if (not defined $opt_verbose);

        my $msg = shift (@_);
        my $log = "$path/$name.log";

        my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst)=localtime(time);
        $wday++;
        $yday++;
        $mon++;
        $year+=1900;
        $isdst++;

        if ($opt_verbose == 0){

		if ($metric =~ /\w/){

    			 print "$msg | $perf\n";

		}

		   	else{

      	print "$msg\n";
		}

        }

	else {
           open(LOG, ">>$log");
           printf LOG ("%02i/%02i/%i - %02i:%02i:%02i => %s\n",$mday,$mon,$year,$hour,$min,$sec,$msg);
           close(LOG);
        }

}
#--------------------------------------------------------------------------------------

sub printUsage {

       print <<EOB

Usage: $name.pl [OPTION]...

        -V, --version      Show version
        -c, --critical     Threshold to critical
        -h, --help         Show help
        -w, --warning      Threshold to warning
        -D, --directory    Diretorio a ser analisado

        -v, --verbose      0 = Print out in screen
                           1 = Send log to file

EOB

}
#--------------------------------------------------------------------------------------

sub printHelp {

		my $help = <<'HELP';


		Insert help program


HELP

		print $help;

}
#--------------------------------------------------------------------------------------
&main


