#!/usr/bin/php
<?php
include "/usr/local/opmon/etc/config.php";
define("DEBUG",false);

$GLOBALS['mod'] = "EXTERNAL";

function main($argv) {

	$params = parse_input_params($argv);
	set_logged_user("opmonadmin");

	$hosts = get_hosts();
	if (!is_array($hosts) || empty($hosts)) {
		print "UNKNOWN - Impossivel encontrar lista de hosts validos.\n";
		return(UNKNOWN);
	}

	$host_id = false;
	foreach($hosts as $host) {
		if ($host->host_name == $params->host_name) {
			$host_id = $host->host_id;
			break;
		}
	}

	if (!$host_id) {
		print "UNKNOWN - Impossivel encontrar host '{$params->host_name}'\n";
		return(UNKNOWN);
	}

	if (DEBUG) {
		print "Host {$params->host_name} encontrado.\n";
	}

	$host = get_host($host_id);
	if (!$host || get_class($host) != 'Host') {
		print "UNKNOWN - Um erro ocorreu durante o processamento. Contate a OpServices\n";
		return(UNKNOWN);
	}

	if (DEBUG)
		print "Procurando Servico...\n";

	$services = $host->get_services();
	$service_id = false;
	foreach ($services as $s) {

		if (DEBUG)
			print "\t\t{$s->get_service_description()}\n";

		if ($s->get_service_description() == $params->service_description) {

			if (DEBUG)
				print "\t\t\tEncontrado! Continuando...\n";

			$service_id = $s->get_service_id();
			break;
		}
	}
	
	if (!$service_id) {
		print "UNKNOWN - Impossivel encontrar servico '{$params->service_description}' no host '{$params->host_name}'\n";
		return(UNKNOWN);
	}
	
	$doc_id = get_documentation_by_object($host_id,$service_id);
	if (!$doc_id) {
		print "OK - Sem documentacoes cadastradas para '{$params->service_description}' no host '{$params->host_name}'\n";
		return(OK);
	}

	$doc = load_documentation($doc_id);
	if (!$doc || get_class($doc) != 'Documentation') {
		print "UNKNOWN - Um erro ocorreu durante o processamento. Contate a OpServices\n";
		return(UNKNOWN);
	}

	$alert_on = time() + ($params->days * 24 * 60 * 60);
	$next_revision = strtotime($doc->next_revision);
	preg_match("/^(\d{4})-(\d{2})-(\d{2}) .+$/",$doc->next_revision,$matches);
	$date_pt_br = $matches[3]."/".$matches[2]."/".substr($matches[1],2,2);

	if (DEBUG) {
		print "Proxima revisao documentacao: {$doc->next_revision}($date_pt_br)\n";
	}

	if ($next_revision <= time()) {
		print "CRITICAL - Documentacao aguardando atualizacao - '{$params->service_description}' no host '{$params->host_name} ($date_pt_br)'\n";
		return(CRITICAL);
	}

	if ($next_revision <= $alert_on) {
		print "WARNING - Documentacao aguardando atualizacao - '{$params->service_description}' no host '{$params->host_name}' ($date_pt_br)\n";
		return(WARNING);
	}

	print "OK - Ultima revisao {$doc->last_revision} proxima em {$doc->next_revision}.\n";
	return(OK);

}

function parse_input_params($argv) {

	// hostname and servicedescription
	if (!isset($argv[1]) || !isset($argv[2]))
		usage();

	$ret = new StdClass();
	$ret->host_name = $argv[1];
	$ret->service_description = $argv[2];
	if (!isset($argv[3])) {
		$ret->days = 15;
	} else {
		$ret->days = $argv[3];
	}

	if (DEBUG) {
		print "Input parameters:\n";
		print_r($ret);
	}

	return $ret;

}

function usage() {
	print "Usage: {$argv[0]} <hostname> <servicedescription> [days]\n";
	exit(UNKNOWN);
}

exit(main($argv));
?>
