#!/usr/bin/php -q
<?php

require_once '/usr/local/opmon/etc/config.php';
require_once '/usr/local/opmon/libexec/php-nagios-plugins/Nagios_Plugin.php';

# ENTERASYS-RESOURCE-UTILIZATION-MIB::etsysResourceCpuLoad5sec.1.1 = INTEGER: 200
# ENTERASYS-RESOURCE-UTILIZATION-MIB::etsysResourceCpuLoad1min.1.1 = INTEGER: 229
# ENTERASYS-RESOURCE-UTILIZATION-MIB::etsysResourceCpuLoad5min.1.1 = INTEGER: 210
# ENTERASYS-RESOURCE-UTILIZATION-MIB::etsysResourceStorageDescr.2.1.0 = STRING: other device
# ENTERASYS-RESOURCE-UTILIZATION-MIB::etsysResourceStorageDescr.3.2.0 = STRING: RAM device
# ENTERASYS-RESOURCE-UTILIZATION-MIB::etsysResourceStorageDescr.4.3.0 = STRING: Flash Images, Configs Other
# ENTERASYS-RESOURCE-UTILIZATION-MIB::etsysResourceStorageSize.2.1.0 = Gauge32: 0
# ENTERASYS-RESOURCE-UTILIZATION-MIB::etsysResourceStorageSize.3.2.0 = Gauge32: 262140
# ENTERASYS-RESOURCE-UTILIZATION-MIB::etsysResourceStorageSize.4.3.0 = Gauge32: 31612
# ENTERASYS-RESOURCE-UTILIZATION-MIB::etsysResourceStorageAvailable.2.1.0 = Gauge32: 0
# ENTERASYS-RESOURCE-UTILIZATION-MIB::etsysResourceStorageAvailable.3.2.0 = Gauge32: 54481
# ENTERASYS-RESOURCE-UTILIZATION-MIB::etsysResourceStorageAvailable.4.3.0 = Gauge32: 22560

define("VERSION", "1.0");
define("ENTERASYS", ".1.3.6.1.4.1.5624.1.2.49.1");
define("CpuLoad1min", ".1.1.1.3.1.1");
define("CpuLoad5min", ".1.1.1.4.1.1");
define("StorageDescr", ".3.1.1.3.2");
define("StorageSize", ".3.1.1.4.3");
define("StorageAvailable", ".3.1.1.5.4");

$np = null;

function set_nagios() {

	# Constructor
	global $np;

	$np = new Nagios_Plugin(
		array (
			'version' => VERSION . " [kb.opservices.com.br]",

			'blurb' => "Developed by:\n\tOpServices\n"
            			. "Author: \nOtavio Honorio - otavio.honorio\@opservices.com.br\n",

			'usage' => "Usage:\n\t%s -H <hostname> -C <communityid> -m <cpu|device>\n"
				. " \t -w <warning> -c <critical> [-d <other|ram|flash>]"
		)
	);

	$np->add_arg("hostname|H=s", "Name of host in OpMon", 1);
	$np->add_arg("communityid|C=i", "Id of community of host in OpMon", 1);
	$np->add_arg("mode|m=s", "Mode of check: device or cpu", 1);
	$np->add_arg("devtype|d=s", "other, ram and flash");
	$np->add_arg("warning|w=i", "Warning value in percentage");
	$np->add_arg("critical|c=i", "Critical value in percentage");

	$np->getopts();

}

function get_snmp($hostname, $community, $oid) {

	$snmp = new SNMPIntegration(
		$community,
		$hostname
	);

	$result = $snmp->walk($oid);

	if (!(sizeof($result))) {
		print "Timeout: No Response from {$hostname}\n";
		exit(3);
	}

	return $result;

}

function get_snmp_cpu($hostname, $community) {

	$cpulist = array();

	$result = get_snmp($hostname, $community, ENTERASYS.CpuLoad1min);
	$cpulist['CpuLoad1min'] = round($result[ENTERASYS.CpuLoad1min] / 10, 2);

	$result = get_snmp($hostname, $community, ENTERASYS.CpuLoad5min);
	$cpulist['CpuLoad5min'] = round($result[ENTERASYS.CpuLoad5min] / 10, 2);

	return $cpulist;

}

function get_snmp_device($hostname, $community, $type) {

	$listdev = array('other', 'ram', 'flash', 'usbFlash');
	$list = array('other' => '.1.0', 'ram' => '.2.0', 'flash' => '.3.0', 'usbFlash', 4.0);

	$string = array('`','~','!','$','%','^','&','*','|','\\','"','<','>','?',',','(',')','=');

	if (!in_array($type,$listdev)) {
		print "Device type, ".$type." not found.\n";
		exit(2);
	}

	$devinfo = array();

	$descr = get_snmp($hostname, $community, ENTERASYS.StorageDescr.$list[$type]);
	$size = get_snmp($hostname, $community, ENTERASYS.StorageSize.$list[$type]);
	$avail = get_snmp($hostname, $community, ENTERASYS.StorageAvailable.$list[$type]);

	$devinfo['descr'] = str_replace($string, "", $descr[ENTERASYS.StorageDescr.$list[$type]]);
	$devinfo['size'] = round($size[ENTERASYS.StorageSize.$list[$type]] / 1024, 3);
	$devinfo['avail'] = round($avail[ENTERASYS.StorageAvailable.$list[$type]] / 1024, 3);
	$devinfo['used'] = $devinfo['size'] - $devinfo['avail'];
	$devinfo['perc'] = round((($devinfo['used'] * 100) / $devinfo['size']),2);

	return $devinfo;

}

function main() {

	global $np;

	set_nagios();

	$comm = SNMPCommunity::get_community_by_id($np->opts['communityid']);

	if ($np->opts['mode'] == "cpu") {

		$metrics = get_snmp_cpu($np->opts['hostname'], $comm);
		
		$threshold = new Nagios_Plugin_Threshold($np->opts['warning'], $np->opts['critical'], 0, 100);

		$np->add_perfdata("CPULoad1min", $metrics['CpuLoad1min'], '%', $threshold);
		$np->add_perfdata("CPULoad5min", $metrics['CpuLoad5min'], '%', $threshold);

		$np->nagios_exit(
			$np->check_threshold($metrics['CpuLoad5min'], $np->opts['warning'], $np->opts['critical']),
                	"CPU Load 1 min: {$metrics['CpuLoad1min']}% - CPU Load 5 min: {$metrics['CpuLoad5min']}%"
        	);

	} else if ($np->opts['mode'] == "device") {

		if (!isset($np->opts['devtype'])) {
			print "Missing parameter: --devtype\n\n";
			$np->print_help();
		}

		$metrics = get_snmp_device($np->opts['hostname'], $comm, $np->opts['devtype']);
		
		$percthreshold = new Nagios_Plugin_Threshold($np->opts['warning'], $np->opts['critical'], 0, 100);

		$np->add_perfdata("Utilization", $metrics['perc'], '%', $percthreshold);

		$warnmb = round((($metrics['used'] * $np->opts['warning']) / 100), 3);
		$critmb = round((($metrics['used'] * $np->opts['critical']) / 100), 3);

		$sizethreshold = new Nagios_Plugin_Threshold($warnmb, $critmb, 0, $metrics['size']);

		$np->add_perfdata("Used", $metrics['used'], 'Mb', $sizethreshold);

		$np->nagios_exit(
			$np->check_threshold($metrics['perc'], $np->opts['warning'], $np->opts['critical']),
                	"{$metrics['descr']} - Utilization ({$metrics['perc']}%): {$metrics['used']}Mb usage of {$metrics['size']}Mb"
        	);

	} else {
		print "Mode {$np->opts['mode']} not support or not found.";
		exit(3);
	}

}

main();

?>
