#!/usr/bin/php
<?php

/**
 * Habilita a exibição de erros (strict)
 */
//error_reporting(E_ALL);

/******************************************************************************
 * Header
 ******************************************************************************

AUTOR: Bruno Miranda
CRIADO EM: 03/02/2016

REVISÕES:
--------------------------------------------------------------

******************************************************************************/

require_once("/var/local/opmon/libexec/php-nagios-plugins/Nagios_Plugin.php");

define("VERSION","1.0");
$np = null;

/**
 * Classe utilizada para realizar as requisicoes necessarias.
 */

class HttpRequest {
	/**
	 * @var resource $curl
	 */
	protected $curl;

	/**
	 * Contem o valor retornado na requisicao ou 'false' em caso de falha.
	 * @var mixed $response
	 */
	protected $response;

	/**
	 * Armazena o erro da ultima requisicao ou string vazia.
	 * @var string $lastError
	 */
	protected $lastError;

	/**
	 * Armazena o usuario que deve ser utilizado para realizar a requisicao.
	 * @var string $user
	 */
	protected $user;

	/**
	 * Armazena a senha que deve ser utilizada para realizar a requisicao.
	 * @var string $pass
	 */
	protected $pass;

	/**
	 * Contem informacoes a respeito da ultima requisicao realizada.
	 * @var mixed $info
	 */
	protected $info;

	/**
	 * Armazena o timeout, em segundos, utilizado para a conexao e o processamento da requisicao.
	 * @var int $timeout (padrao: 15s)
	 */
	protected $timeout;

	public function __construct()
	{
		$this->startClient();
	}

	public function __destruct()
	{
		$this->closeConnection();
	}

	/**
	 * O metodo startClient eh utilizado para iniciar as propriedades da classe
	 * e o curl com as opcoes padrao.
	 */
	protected function startClient()
	{

		$this->curl = curl_init();

    	curl_setopt($this->curl, CURLOPT_HEADER, false);
    	curl_setopt($this->curl, CURLOPT_FOLLOWLOCATION, false);
		curl_setopt($this->curl, CURLOPT_RETURNTRANSFER, true);
		curl_setopt($this->curl, CURLOPT_SSL_VERIFYPEER, false);
		curl_setopt($this->curl, CURLOPT_SSL_VERIFYHOST, false);
		curl_setopt($this->curl, CURLOPT_FAILONERROR, true);
		curl_setopt($this->curl, CURLOPT_POST, false);
		curl_setopt($this->curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);

		$this->response		= null;
		$this->lastError	= '';
		$this->user			= null;
		$this->pass			= null;
		$this->info			= null;
		$this->timeout		= 15;

	}

	/**
	 * Fecha a sessao e encerra todos os recursos.
	 */
	protected function closeConnection()
	{
		curl_close($this->curl);
		$this->curl = null;
	}

	/**
	 * Metodo utilizado para definir opcoes de header para a requisicao.
	 * @link http://php.net/manual/pt_BR/function.curl-setopt.php
	 * @param array $header (array de strings)
	 * @return $this
	 */
	public function setHeader($header = array())
	{
		curl_setopt($this->curl, CURLOPT_HTTPHEADER, $header);
		return $this;
	}

	/**
	 * Metodo utilizado para definir a senha utilizada na requisicao. A senha
	 * sera utilizada apenas se o usuario for definido.
	 * @param string $password
	 * @return $this
	 */
	public function setPassword($password)
	{
		$this->pass = $password;
		return $this;
	}

	/**
	 * Metodo utilizado para retornar o usuario utilizado na requisicao.
	 * @return string
	 */
	public function getUsername()
	{
		return $this->user;
	}

	/**
	 * Metodo utilizado para definir o usuario utilizado na requisicao.
	 * @param string $user
	 * @return $this
	 */
	public function setUsername($user)
	{
		$this->user = $user;
		return $this;
	}

	/**
	 * Retorna informacoes a respeito da ultima requisicao realizada.
	 * @return mixed
	 */
	public function getInfo()
	{
		return $this->info;
	}

	/**
	 * Este metodo define o timeout de conexao e execucao com o mesmo valor.
	 * @param int $timeout
	 */
	public function setTimeout($timeout)
	{
		if (( ! is_numeric($timeout)) || ($timeout < 0)) {
			throw new InvalidArgumentException(
				'O timeout deve ser um numero maior do que zero.'
			);
		}

		$this->timeout = $timeout;
	}

	/**
	 * Metodo utilizado para realizar as requisicoes com as opcoes definidas
	 * nos demais metodos da classe.
	 * @param string $url
	 */
	public function doRequest($url)
	{
		$this->last_error = '';
		curl_setopt($this->curl, CURLOPT_URL, $url);
		curl_setopt($this->curl, CURLOPT_CONNECTTIMEOUT, $this->timeout);
		curl_setopt($this->curl, CURLOPT_TIMEOUT, $this->timeout);

		if ( ! is_null($this->user)) {
			$auth = sprintf(
				"%s:%s",
				$this->user,
				$this->pass
			);

			curl_setopt($this->curl, CURLOPT_USERPWD, $auth);
		}

		$this->response = curl_exec($this->curl);
		$this->info = curl_getinfo($this->curl);

		if ( ! $this->response) {
			$this->last_error = sprintf(
				"%s-%s",
				curl_errno($this->curl),
				curl_error($this->curl)
			);
		}
	}

	/**
	 * Retorna o erro da ultima requisicao, caso tenha ocorrido algum.
	 * @return string
	 */
	public function getLastError()
	{
		return $this->lastError;
	}

	/**
	 * Retorna response da ultima requisicao.
	 * @link http://php.net/manual/pt_BR/function.curl-exec.php
	 * @return mixed
	 */
	public function getResponse()
	{
		return $this->response;
	}
}

/******************************************************************************
* Exibe o manual do plugin
*******************************************************************************/

function getGuideLine() {

    print <<<EOF

------------------------------------------
Manual de exemplo.
------------------------------------------

Descrição do plugin:
    Este plugin monitora a disponibilidade do sistema da Ionic.

Funcionamento:
    O plugin abre uma conexao com o endereco https://push.ionic.io/api/v1/status
e tenta verificar o status de uma mensagem invalida. Se for possivel abrir uma
conexao e um json valido de erro for retornado, o status sera considerado como
OK. De qualquer outra forma, sera retornado CRITICAL.

Exemplos de execução e retorno do comando:

    ./check_ionic_status.php

EOF;

    exit (OK);

}

/******************************************************************************
* Seta os atributos da variavel global $np
******************************************************************************/

function setNagios() {

    # Constructor
    global $np;

    $np = new Nagios_Plugin(
        array (
            'version' => VERSION . " [www.opservices.com.br/suporte]",
            'blurb' => "Developed by:\n\tOpServices\n"
                . "Author: Bruno Miranda\n\t - bruno.miranda\@opservices.com.br\n",
            'usage' => "Usage:\n\t%s [<options>]",

        )
    );

	$np->add_arg("user|u=s","Set a username to do the request");
	$np->add_arg("password|p=s","Set a password to do the request");
	$np->add_arg("man","Show guideline");
    $np->getopts();
}


function main()
{
	global $np;

	setNagios();

	if (isset($np->opts['man'])) {
		getGuideLine();
	}

	$http = new HttpRequest();

	$http->setUsername("59e66697dd284c785842dbd316c7029a758b1551a72f44da");
	if (isset($np->opts['user'])) {
		$http->setUsername($np->opts['user']);
	}

	if (isset($np->opts['password'])) {
		$http->setPassword($np->opts['password']);
	}

	if (isset($np->opts['timeout'])) {
		$http->setTimeout($np->opts['timeout']);
	}


	$http->setHeader(
			array(
				'Content-Type: application/json',
				'X-Ionic-Application-Id: 8bba580d'
			))
		->doRequest('https://push.ionic.io/api/v1/status/testing_connection');

	$response = json_decode($http->getResponse());
	$request_error = $http->getLastError();

	$status	= (empty($request_error)) ? 0 : 2;

	$msg = 'Request didn\'t return the expected error.';
	$expected_error = 'Message with id testing_connection not found';

	if ((isset($response->errors[0]))
		&& ($expected_error === $response->errors[0])) {
		$msg = $expected_error;
	} else {
		$status = 2;
	}

	if (isset($np->opts['verbose'])) {
		fprintf(
			STDERR,
			"Request info:\n%s\n",
			var_export($http->getInfo(), true)
		);

		fprintf(
			STDERR,
			"Request error:\n%s\n",
			var_export($http->getLastError(), true)
		);
	}

	$np->nagios_exit($status, $msg);
}

main();

/* vim: set smartindent tabstop=4 shiftwidth=4 softtabstop=4 expandtab[ENTER] */
