#!/usr/bin/php
<?php

include "/usr/local/opmon/etc/config.php";

function help() {
	print "check_opmon_hosts.php -g <hostgroup name> [-w <warning>] [-s] [-c <critical>] [-e] [-h]\n";
	print "Usage:\n";
	print "\t -g <hostgroup name> 	- hostgroup to get hosts status\n";
	print "\t -w <warning>		- hosts problems warning threshold\n";
	print "\t -c <critical>		- hosts problems critical threshold\n";
	print "\t -h			- show this message\n";
	print "\t -e			- extended(also show services counters)\n";
	print "\t -s			- consider soft state as a problem\n";
	return OK;
}

function main() {

	set_logged_user("opmonadmin");

	$options = getopt("g:hw:c:es");
	$hosts = array();

	if (isset($options['h']) || !isset($options['g'])) {
		return help();
	}

	$filter_obj = new StdClass();
	$filter_obj->search = $options['g'];	
	if (!isset($options['s'])) {
		$filter_obj->state_type = 1;
	}

	$a_status = get_hostgroups_status(FALSE, FALSE, FALSE, FALSE, $filter_obj);
	if (!isset($a_status->data) || !is_array($a_status->data)) {
		print "Unable to retrieve hostgroup status\n";
		return UNKNOWN;
	}

	$warning = NULL;
	if (isset($options['w'])) {
		$warning = (int)$options['w'];
	}

	$critical = NULL;
	if (isset($options['c'])) {
		$critical = (int)$options['c'];
	}

	foreach($a_status->data as $hg) {
		if (isset($hg->group_view) && $hg->group_view) {
			if ($hg->hostgroup_name == $options['g']) {

				if (!isset($hg->current_state) || !is_array($hg->current_state) || count($hg->current_state) != 3) {
					print "Unexpected error, please contact opservices support team\n";
					return UNKNOWN;
				}

				print sprintf("Hosts on %s hostgroup: %d - ", $options['g'],
				                                              array_sum($hg->current_state)
				);

				print sprintf("UP:%d DOWN:%d UNREACHABLE:%d ", $hg->current_state[OK],
				                                               $hg->current_state[DOWN],
				                                               $hg->current_state[UNREACHABLE]
				);

				$total_problems = $hg->current_state[DOWN] + $hg->current_state[UNREACHABLE];
				print sprintf("|hosts_total=%d;;;; hosts_up=%d;;;; hosts_down=%d;;;; hosts_unreachable=%d;;;; hosts_problems=%d;%d;%d;; ", 
				                                                                                 array_sum($hg->current_state),
				                                                                                 $hg->current_state[OK],
				                                                                                 $hg->current_state[DOWN],
				                                                                                 $hg->current_state[UNREACHABLE],
				                                                                                 $total_problems,
				                                                                                 $warning,
				                                                                                 $critical
				);

				if (isset($options['e'])) { // extended info

					$stat = array();
					$stat[OK] = 0;
					$stat[WARNING] = 0;
					$stat[CRITICAL] = 0;
					$stat[UNKNOWN] = 0;

					$hg_filter = new StdClass();
					$hg_filter->hostgroup_name = $options['g'];
					if (!isset($options['s'])) {
						$hg_filter->state_type = 1;
					}

					$svc_status = get_services_status(FALSE,FALSE,FALSE,FALSE,$hg_filter);
					if (is_object($svc_status) && isset($svc_status->data) && is_array($svc_status->data)) {
						foreach($svc_status->data as $svc) {
							if (isset($svc->service_description)) {
								$stat[$svc->current_state]++;
							}
						}
					}

					print sprintf("services_total=%d;;;; services_ok=%d;;;; services_warning=%d;;;; services_critical=%d;;;; services_unknown=%d;;;; ", 
					                                                                         array_sum($stat),
					                                                                         $stat[OK],
					                                                                         $stat[WARNING],
					                                                                         $stat[CRITICAL],
					                                                                         $stat[UNKNOWN]
					);
				}

				print "\n";

				if (!is_null($critical) && $total_problems > $critical)
					return CRITICAL;

				if (!is_null($warning) && $total_problems > $warning)
					return WARNING;

				//get_hostgroup_id_by_name()
				return OK;
			}
		}
	}

	print sprintf("Unable to locate host group %s\n",$options['g']);
	return UNKNOWN;
}

exit(main());

?>
