#!/usr/bin/php
<?php

require_once '/usr/local/opmon/etc/config.php';
require_once '/usr/local/opmon/libexec/php-nagios-plugins/Nagios_Plugin.php';

define("VERSION", "2.3");
define("TELNET_PORT", 23);
define("USER_LOGIN_SECURE", 'port-security port-mode userlogin-secure');
define("MAX_MAC_COUNT", 'port-security max-mac-count 1');
define("RETRY_TIME", 100);

$np = null;

/*******************************************************************************
 * Exibir o manual do software
 ********************************************************************************/

function getGuideLine()
{

    $name = basename(__FILE__);
    $realpath = realpath(__FILE__);
    print <<<EOF

-------------------------------------------------------------------------------
Manual de exemplo.
-------------------------------------------------------------------------------

Descrição do plugin:
    Verifica a quantidade de interfaces inseguras no switch 3com.

Instalação:
    Copiar este plugin para a pasta de plugins no path abaixo:
    /usr/local/opmon/libexec/opservices.

    Dar permissão de execução( chmod +x $realpath )

Dependências:
    Nagios_Plugins para php

Funcionamento:
    Obtem as configurações de interface dos switchs 3com executando commandos
    através do telnet.

    O comando executado é o "display current-configuration interface". Caso
    queira visualizar o retorno do comando basta utilizar o modo verbose.

    Após o obter a configuração o plugin irá verificar quais interfaces estão
    com os módulos de segurança desabilitados e gerará uma porcentagem baseada na
    seguinte formula: X * 100 / Y, sendo 'X' a quantidade de interfaces inseguras
    e 'Y' a soma das interfaces Ethernet e GigabitEthernet.

Exemplos de execução:
    ./$name -H <hostname | IP> -u <usuário do telnet> -P <password> -w 2 -c 4 -v
    [modo verbose]

    ./$name -H <hostname | IP> -u <usuário do telnet> -P <password> -w 2 -c 4
    Number of Interfaces: 236 - No Security: 47%


EOF;

    exit(OK);
}

/*******************************************************************************
 * Seta os atributos da variável global $np
 ********************************************************************************/

function set_nagios()
{

    # Constructor
    global $np;

    $np = new Nagios_Plugin(
        array (
            'version' => VERSION . " [www.opservices.com.br/suporte]",
            'blurb' => "Developed by:\n\tOpServices\n"
            . "Author: \n\tSidney Souza - sidney.souza\@opservices.com.br\n",
            'usage' => "Usage:\n\t%s -H <hostname> -u <username> -P <password>\n"
            . " \t -w <warning> -c <critical> [--man] [-p <port>]"
        )
    );

    $np->add_arg("hostname|H=s", "Name of host in OpMon", true);
    $np->add_arg("port|p=i", "Telnet port to connect");
    $np->add_arg("warning|w=i", "Warning value in percentage");
    $np->add_arg("critical|c=i", "Critical value in percentage");
    $np->add_arg("username|u=s", "Connection username", true);
    $np->add_arg("password|P=s", "Connection password", true);
    $np->add_arg("timeout|t=i", "Telnet timeout");
    $np->add_arg("man", "Show guideline");

    $np->getopts();

}


function increment_metrics_according_to_security_value(Array &$metrics, $val)
{
    switch ($val) {
        case 3:
            $metrics['fullActive']++;
            break;
        case 2:
            $metrics['maxMac']++;
            break;
        case 1:
            $metrics['userLogin']++;
            break;
        case 0:
            $metrics['none']++;
            break;
    }
}

/*******************************************************************************
 * Valida linha corrente do arquivo passada por parâmetro.
 *
 * Retorna se a linha do arquivo se refere a uma interface e se esta interface
 * é uma das consideradas válidas
 *
 * @param String $line_content Conteúdo da minha corrente do arquivo
 * @return Array $ar Array com as informações obtidas.
 *                   Posições:
 *                   0 => Se a linha é uma interface
 *                   1 => Se for uma interface, diz se ela é válida
 *******************************************************************************/
function verify_interfaces($line_content)
{
    $is_interface =
        preg_match("/interface (?P<interface>.*)/", trim($line_content), $matchs);

    $is_a_valid_interfaces = preg_match("/Ethernet/", $matchs['interface']);

    return array($is_interface, $is_a_valid_interfaces);
}

/*******************************************************************************
 * Verifica o nível de segurança de cada interface
 * @return Integer $value Valor que determina o nível de segurança
 *******************************************************************************/
function get_security_value($file, &$line, $number_of_lines)
{
    $max_mac_count = $user_login_secure = 0;
    while (! preg_match("/^#/", trim($file[$line])) && $line < $number_of_lines) {
        if (preg_match("/" . MAX_MAC_COUNT . "/", trim($file[$line]))) {
            $max_mac_count = 2;
        }

        if (preg_match("/" . USER_LOGIN_SECURE . "/", trim($file[$line]))) {
            $user_login_secure = 1;
        }

        $line++;
    }
    return $max_mac_count + $user_login_secure;
}

function get_host_information()
{
    global $np;

    if (filter_var($np->opts['hostname'], FILTER_VALIDATE_IP)) {
        $np->opts['host_address'] = $np->opts['hostname'];
        return;
    }

    $host = get_host_by_name($np->opts['hostname']);
    if (! $host) {
        $np->nagios_die('Hostname not found on OpMon');
    }
    $np->opts['host_address'] = $host->get_address();
}

/*******************************************************************************
 * Executa os comandos necessários no equipamento para obter a configuração
 * @return String $configuration Configurações obtidas do telnet.
 *******************************************************************************/
function get_file_content()
{

    global $np;

    $telnet = new TelnetConnector();

    if (isset($np->opts['verbose'])) {
        $telnet->set_verbose();
    }

    try {
        $telnet->open($np->opts['host_address']);
    } catch (TelnetConnectorException $e) {
        $np->nagios_die($e->getMessage());
    }


    try {
        $telnet->execute('/username:/i', $np->opts['username']);
        $telnet->execute('/password:/i', $np->opts['password']);
        $telnet->execute('/.*/i', "\n\n");

        $telnet->clear_buffer();

        $telnet->execute('/>/', 'display current-configuration interface');

        try {
            $telnet->set_timeout(5);
            $telnet->execute('/Unrecognized/i', '');
            $np->nagios_die('Unrecognized command found', CRITICAL);
        } catch (TelnetConnectorException $e) {
            $telnet->set_timeout($np->opts['timeout']);
        }

        try {
            $telnet->execute('/.*(return|>).*/', 'quit');
        } catch (Exception $e) {
        }

        $configuration = $telnet->get_buffer();
        $telnet->close();

    } catch (TelnetConnectorException $e) {
        $np->nagios_die($e->getMessage(), CRITICAL);
    } catch (InvalidArgumentException $e) {
        $np->nagios_die($e->getMessage(), UNKNOWN);
    }

    $telnet->close();

    return explode("\n", $configuration);
}

/*******************************************************************************
 * Rotina principal do programa
 *******************************************************************************/
function main()
{
    set_nagios();

    global $np;
    if (isset($np->opts['man'])) getGuideLine();
    if(! isset($np->opts['hostname'])) $np->nagios_die("Hostname is required");
    if(! isset($np->opts['username'])) $np->nagios_die("Username is required");
    if(! isset($np->opts['password'])) $np->nagios_die("Password is required");
    if(! isset($np->opts['port'])) $np->opts['port'] = TELNET_PORT;
    if(! isset($np->opts['timeout'])) $np->opts['timeout'] = RETRY_TIME;

    if (! isset($np->opts['warning']) && !isset($np->opts['critical'])) {
        $np->nagios_exit(CRITICAL, "Need to define warning and critical values!");
    }

    get_host_information();
    $file = get_file_content();

    $number_of_lines = sizeof($file);

    $metrics = array();
    $metrics['fullActive'] = 0;
    $metrics['maxMac'] = 0;
    $metrics['userLogin'] = 0;
    $metrics['none'] = 0;

    $number_of_interfaces = 0;
    for ($line = 1; $line < $number_of_lines; $line++) {
        list($is_interface, $is_a_valid_interfaces) = verify_interfaces($file[$line]);

        if (! $is_interface || ! $is_a_valid_interfaces) {
            continue;
        }

        $number_of_interfaces++;
        $security_value = get_security_value($file, $line, $number_of_lines);
        increment_metrics_according_to_security_value($metrics, $security_value);
    }

    $metrics['percNoSecurity'] = (int) ($metrics['none'] * 100 / $number_of_interfaces);

    $np->add_perfdata("fullSecurity", $metrics['fullActive']);
    $np->add_perfdata("maxMacCount", $metrics['maxMac']);
    $np->add_perfdata("userLoginSecure", $metrics['userLogin']);
    $np->add_perfdata("noSecurity", $metrics['none']);

    $threshold = new Nagios_Plugin_Threshold($np->opts['warning'], $np->opts['critical'], 0, 100);

    $np->add_perfdata("percNoSecurity", $metrics['percNoSecurity'], '', $threshold);

    $np->nagios_exit(
        $np->check_threshold($metrics['percNoSecurity'], $np->opts['warning'], $np->opts['critical']),
        "Number of Interfaces: {$number_of_interfaces} - No Security: {$metrics['percNoSecurity']}%"
    );
}

main();

/* vim: set smartindent tabstop=4 shiftwidth=4 softtabstop=4 expandtab : */
