#!/bin/bash

################################################################################
# AUTOR: Guilherme Fontans
# CRIADO EM: 05/11/2015
################################################################################

readonly OK=0
readonly WARNING=1
readonly CRITICAL=2
readonly UNKNOWN=3
readonly WARNING_DEFAULT=30
readonly CRITICAL_DEFAULT=10
readonly VERSION=1.0

function getRemainingDays() {

	local remainingDays=""

	#Captura da data atual
	local currentDate=$(date +%s)

	#Captura da data de expiração do domínio
	local expireDate=$(whois ${domain} | awk ' /expires/ {print $2}'| tr -d '\r')


	if [ -n "${expireDate}" ]; then
		expireDate=$(date -d $expireDate +%s)
		remainingDays=$((($expireDate - $currentDate)/60/60/24))
		echo $remainingDays
	fi
}

function usage(){
	local programName=$( basename $0  )
	cat <<-EOF
		Usage:
		    ${programName} -d <domain> -w [warning_value] -c [critical_value]
	EOF
}

function help(){

	local usage=$( usage  )

	cat <<-EOF

		Version: ${VERSION}

		Developed by:
		    Opservices

		Author:
		    Guilherme Fontans - guilherme.fontans@opservices.com.br

			Dependencies:
		    jwhois.x86_64

		${usage}

		--usage
		    Print usage information
		-h, --help
		    Print detailed help screen
		-w, --warning=INTEGER
		    Warning value (default: 30)
		-c, --critical=INTEGER
		    Critical value (default: 10)
		-d, --domain=STRING
		    Domain for verification

	EOF

}

function getOptions(){
	ARG="$@"

	eval set -- "$@"

	while true ; do
		case "$1" in
			--usage)
				usage
				exit ${OK}
				;;
			-h|--help)
				help
				exit ${OK}
				;;
			-w|--warning)
				warning=${2}
				shift 2
				;;
			-c|--critical)
				critical=${2}
				shift 2
				;;
			-d|--domain)
				domain=${2}
				shift 2
				;;
			*)
				shift 2
				break;;
		esac
	done
	#valida se o domínio foi informado.
	if [ -z ${domain} ]; then
		usage
	fi
}

function checkThreshold(){

	local value=${1}
	local status=${OK}
	local warning=${warning:=$WARNING_DEFAULT}
	local critical=${critical:=$CRITICAL_DEFAULT}

	if [ ${value} -le ${warning} -a ${value} -ge ${critical} ]; then
		status=${WARNING}
	elif [ ${value} -le ${critical} ]; then
		status=${CRITICAL}
	fi

	echo ${status}
}

function main(){

	getOptions $(
		getopt -a -o hw:c:d: -l "help usage warning: critical: domain:" -n "$0" -- "$@"
	)

	local outMessage=''
	local perfData=''
	local daysRemaining=$( getRemainingDays )

	#valida se a variavel daysRemaining é nula
	if [ -z ${daysRemaining} ]; then
		echo "Não foi possível obter a data de expiração do domínio"
		exit ${UNKNOWN}
	fi

	outMessage="Dias restantes para expiração do domínio: ${daysRemaining}"

	echo ${outMessage}
	exit $(checkThreshold $daysRemaining)
}

main "$@"
