#!/usr/bin/perl

use Getopt::Long;
use strict;

our $version = "2.1";

# globals
our $snmpwalk = "/usr/bin/snmpwalk -t 120 ";

our $opt_host = undef;
our $opt_comm = undef;
our $opt_opt = undef;
our $opt_warn = undef;
our $opt_crit = undef;
our $opt_help = undef;
our $opt_verb = undef;
our $opt_invert = undef;
our $opt_version = undef;
our $opt_version2 = undef;
our $opt_blank = undef;
our $opt_delta = undef;
my $oid_base = '.1.3.6.1.4.1.334.72.1.1.1.1.2';


sub main {
	check_options();
	count_options();
	
	# set SNMP version
	if (defined($opt_version2)) {
		$snmpwalk = $snmpwalk." -v2c";
	}else{
		$snmpwalk = $snmpwalk." -v1";
	}
	
	# set SNMP host
	$snmpwalk = $snmpwalk." $opt_host";
	print "Host: <$opt_host>\n" if ($opt_verb);

	# set SNMP community
	$snmpwalk = $snmpwalk." -c $opt_comm $oid_base";
	print "Community: <$opt_comm>\n" if ($opt_verb);
	
	# Start SNMP thread
	
	my @dirty = `$snmpwalk`; chomp(@dirty);
	my $count = 0;
	my $return = -1;
	$opt_opt =~ s/\(/\\\(/g;
	$opt_opt =~ s/\)/\\\)/g;
	foreach (@dirty) {
		if ( m/^.*\".*$opt_opt.*=.*\".*$/ ) {
			$return = $_;
			$count++;
		}
	}

	if (($return == -1 || $count > 1) && !$opt_blank) {
		print "UNKNOWN - Impossivel encontrar valor para $opt_opt\n";
		exit(3);
	}

	print "Command: <$snmpwalk>\n" if ($opt_verb);
	print "Snmpwalk result: $return\n", if ($opt_verb);

	my $opt_str;
	my $value;
	if ($return =~ m/^.*[\d\.]+ = STRING: \"(.*) = (\d*)\"$/i) {
		$opt_str = $1;
		$value = $2;

		$opt_str =~ s/[\.]+/ /;
	} else {
		$return =~  m/^.*[\d\.]+ = STRING: \"(.*) = (.*)\"$/i;
		$opt_str = $1;
		$value = $2;
	}

	$opt_str =~ s/[\\]+/ /g;
	$value =~ s/[\\]+/ /g;

	if ($opt_blank && (!$value)){
		$opt_str = $opt_opt;
		$value = 0;
	}
 	#Delta	
	if ($opt_delta){
		my $delta_path = "/usr/local/opmon/libexec/templates/lotus-notes";
		open(FILE,"$opt_host-$opt_opt-delta.log");
		my $delta = <FILE>;
		close(FILE);
		open(FILE,">$opt_host-$opt_opt-delta.log");
		print FILE $value;
		close(FILE);
		$value = (($value + $delta) / 2); 
	}	

	if (defined $opt_crit) {
		if (($value>=$opt_crit) && (not defined $opt_invert)) {
			print "Critical - $opt_str = $value | '$opt_opt'=$value;$opt_warn;$opt_crit;0;\n";
			exit(2);
		}elsif (($value>=$opt_warn) && (not defined $opt_invert)) {
			print "Warning - $opt_str = $value | '$opt_opt'=$value;$opt_warn;$opt_crit;0;\n";
			exit(1);
		}elsif (($value<=$opt_crit) && (defined $opt_invert)) {
			print "Critical - $opt_str = $value | '$opt_opt'=$value;$opt_warn;$opt_crit;0;\n";
			exit(2);
		}elsif (($value<=$opt_warn) && (defined $opt_invert)) {
			print "Warning - $opt_str = $value | '$opt_opt'=$value;$opt_warn;$opt_crit;0;\n";
			exit(1);
		}else{
			print "Ok - $opt_str = $value | '$opt_opt'=$value;$opt_warn;$opt_crit;0;\n";
			exit(0);
		}
	}else{
		print "$opt_str = $value\n";
		exit(2) if ($value =~ /err/i);
		exit(0);
	}

}

sub check_options {
	Getopt::Long::Configure ("bundling");
	GetOptions(
	   'H:s'   => \$opt_host,	'hostname:s'  => \$opt_host,
	   'C:s'   => \$opt_comm,	'community:s' => \$opt_comm,
	   'O:s'   => \$opt_opt,	'option:s'    => \$opt_opt,
	   'w:i'   => \$opt_warn,	'warning:i'   => \$opt_warn,
	   'c:i'   => \$opt_crit,	'critical:i'  => \$opt_crit,
	   '2'     => \$opt_version2,	'v2c'         => \$opt_version2,
	   'h'     => \$opt_help,	'help'        => \$opt_help,
	   'v'     => \$opt_verb,	'verbose'     => \$opt_verb,
	   'V'     => \$opt_version,	'version'     => \$opt_version,
	   'b'     => \$opt_blank,	'blank'       => \$opt_blank,
	   'd'     => \$opt_delta,	'delta'       => \$opt_delta,
	);


	if (defined($opt_help)) {
		print_help();
		exit(-1);
	}
	
	if (defined($opt_version)) {
		print_version();
		exit(-1);
	}

	if (not defined($opt_host)) { 
		print "No host defined!\n";
		print_usage();
		exit(-1);
	}

	if ((defined($opt_crit)) && (not defined($opt_warn))) {
		print "You must set warning AND critical threshold!\n";
		print_usage();
		exit(-1);
	}
	
	if ((not defined($opt_crit)) && (defined($opt_warn))) {
		print "You must set warning AND critical threshold!\n";
		print_usage();
		exit(-1);
	}
	
	$opt_invert = 1 if ($opt_warn>$opt_crit);

}

sub print_help {
	print "\nLotus Notes SNMP collector version ", $version, "\n";
	print "(c)2006 - 2007 - OpServices\n\n";
	print_usage();
	print <<HELP;
-H, --hostname=HOST
   name or IP address of host to check
-C, --community=COMMUNITY NAME
   community name for the host's SNMP agent (Default: public)
-O, --option=OPTION
   option to query in lotus mib ( See options below )
-2, --v2c
   use snmp v2c (Default: v1)
-w, --warning
   threshold in integer for warning
-c, --critical
   threshold in integer for critical
-b, --blank
   print OK when blank data returns
-h, --help
   print this help message
-v, --verbose
   print extra debugging information
-V, --version
   prints version number
-d, --delta
   enable delta 

HELP
}

sub print_usage {
	print "Usage:\n\t $0 -H <host> -C <snmp_community> -O <option> -w <warning value> -c <critical value> [-2] [-v]\n\n";	
}

sub print_version {
	print "$0 version : $version\n";
}


our @validvalues = (
		'ADMINP.DirectoryDocumentsModified',
		'ADMINP.RelativeResponsesAdded',
		'Agent.Daily.AccessDenials',
		'Agent.Daily.ScheduledRuns',
		'Agent.Daily.TriggeredRuns',
		'Agent.Daily.UnsuccessfulRuns',
		'Agent.Daily.UsedRunTime',
		'Agent.Hourly.AccessDenials',
		'Agent.Hourly.ScheduledRuns',
		'Agent.Hourly.TriggeredRuns',
		'Agent.Hourly.UnsuccessfulRuns',
		'Agent.Hourly.UsedRunTime',
		'Calendar.Total.All.Appts.Reservations',
		'Calendar.Total.All.Users.Resources',
		'Calendar.Total.Appts',
		'Calendar.Total.Reservations',
		'Calendar.Total.Resources',
		'Calendar.Total.Users',
		'Database.DAFailoverCount',
		'Database.DARefreshServerInfoCount',
		'Database.DAReloadCount',
		'Database.Database.BufferPool.Maximum.Megabytes',
		'Database.Database.BufferPool.MM.Reads',
		'Database.Database.BufferPool.MM.Writes',
		'Database.Database.BufferPool.Peak.Megabytes',
		'Database.Database.BufferPool.PerCentReadsInBuffer',
		'Database.DbCache.CurrentEntries',
		'Database.DbCache.DatabaseLinkEntries',
		'Database.DbCache.HighWaterMark',
		'Database.DbCache.Hits',
		'Database.DbCache.InitialDbOpens',
		'Database.DbCache.Lookups',
		'Database.DbCache.MaxBucketLength',
		'Database.DbCache.MaxEntries',
		'Database.DbCache.NumBuckets',
		'Database.DbCache.NumBucketsUsed',
		'Database.DbCache.OvercrowdingRejections',
		'Database.DbCache.Size',
		'Database.DbOpen.FoundInDbCacheExpanded',
		'Database.DbOpen.FoundInDbCacheUnexpanded',
		'Database.DbOpen.FoundInDBQ.Expanded',
		'Database.DbOpen.FoundInDBQ.Unexpanded',
		'Database.DbOpen.FoundInDBQ.WithRLock',
		'Database.DbOpen.FoundInDBQ.WithWLock',
		'Database.DbOpen.FoundLinkInDbCache',
		'Database.DbOpen.InitialDbOpens',
		'Database.DbOpen.NameExpansionsNeeded',
		'Database.DBUCache.Added',
		'Database.DBUCache.AgedOut',
		'Database.DBUCache.Hits',
		'Database.DBUCache.MaxEntries',
		'Database.DBUCache.SecsInCache.Ave',
		'Database.DBUCache.SecsInCache.Max',
		'Database.DBUCache.SecsInCache.Min',
		'Database.ExtMgrPool.Peak',
		'Database.ExtMgrPool.Used',
		'Database.FreeHandleStack.FreeHandleStackHits',
		'Database.FreeHandleStack.HandleAllocations',
		'Database.FreeHandleStack.MissRate',
		'Database.LDAP.NAMELookupBindFailures',
		'Database.LDAP.NAMELookupBinds',
		'Database.LDAP.NAMELookupBytesReceived',
		'Database.LDAP.NAMELookupEntries',
		'Database.LDAP.NAMELookupFailures',
		'Database.LDAP.NAMELookupTotal',
		'Database.LDAP.NAMELookupTotalLookupTime',
		'Database.MonitorPool.Event.Used',
		'Database.MonitorPool.Monitors.Used',
		'Database.MonitorPool.Size',
		'Database.NAMELookupCacheCacheSize',
		'Database.NAMELookupCacheHashSize',
		'Database.NAMELookupCacheHits',
		'Database.NAMELookupCacheLookups',
		'Database.NAMELookupCacheMaxSize',
		'Database.NAMELookupCacheMisses',
		'Database.NAMELookupCacheNoHitHits',
		'Database.NAMELookupCachePool.Peak',
		'Database.NAMELookupCachePool.Used',
		'Database.NAMELookupCacheResets',
		'Database.NAMELookupMisses',
		'Database.NAMELookupTotal',
		'Database.NAMELookupTotalLookupTime',
		'Database.NIFPool.Peak',
		'Database.NIFPool.Used',
		'Database.NSFPool.Peak',
		'Database.NSFPool.Used',
		'Database.NSF.ClusterHashTable.EntriesWithSameIndex',
		'Database.NSF.ClusterHashTable.FreedEntriesOnCleanup',
		'Database.NSF.ClusterHashTable.HashedEntries',
		'Database.NSF.ClusterHashTable.HashIsFull',
		'Database.NSF.ClusterHashTable.MissedHashHits',
		'Database.NSF.ClusterHashTable.SuccessfullHashHits',
		'Database.NSF.Replicate.NotesMergedBack',
		'Database.NSF.Replicate.NotesReceived',
		'Database.NSF.Replicate.NotesReopened',
		'Database.NSF.Replicate.NotesSent',
		'Database.NSF.Replicate.SCR.DbOutOfSync',
		'Database.NSF.Replicate.SCR.DeferredEvent',
		'Database.NSF.Replicate.SCR.DeleteMerge',
		'Database.NSF.Replicate.SCR.Deletions',
		'Database.NSF.Replicate.SCR.FolderUpdates',
		'Database.NSF.Replicate.SCR.HeaderUpdates',
		'Database.NSF.Replicate.SCR.MaxQueuedMemoryMB',
		'Database.NSF.Replicate.SCR.NoteUpdateFolderMerge',
		'Database.NSF.Replicate.SCR.NoteUpdates',
		'Database.NSF.Replicate.SCR.PastConserveMem',
		'Database.NSF.Replicate.SCR.PastMaxMem',
		'Database.NSF.Replicate.SCR.SrvDbMatch',
		'Database.NSF.Replicate.SCR.SrvDbOpens',
		'Database.NSF.Replicate.SCR.SrvDbUseLRU',
		'Database.NSF.Replicate.SCR.SrvSrcSameDb',
		'Database.NSF.Replicate.SCR.SrvTotalOps',
		'Database.NSF.Replicate.SCR.UnreadUpdates',
		'Database.NSF.Replicate.UnreadMarks.ChunkLookups',
		'Database.NSF.Replicate.UnreadMarks.ChunksScanned',
		'Database.NSF.Replicate.UnreadMarks.ChunksSkimmed',
		'Database.NSF.Replicate.UnreadMarks.DroppedFutureEntries',
		'Database.NSF.Replicate.UnreadMarks.DroppedOldEntries',
		'Database.NSF.Replicate.UnreadMarks.FullReplications',
		'Database.NSF.Replicate.UnreadMarks.LocalMaxChunks',
		'Database.NSF.Replicate.UnreadMarks.LocalUnreadOperations',
		'Database.NSF.Replicate.UnreadMarks.MessagesReceived',
		'Database.NSF.Replicate.UnreadMarks.MessagesSent',
		'Database.NSF.Replicate.UnreadMarks.OperationsReceived',
		'Database.NSF.Replicate.UnreadMarks.OperationsSent',
		'Database.NSF.Replicate.UnreadMarks.UsersActive',
		'Database.NSF.Replicate.UnreadMarks.UsersActiveMax',
		'Database.NSF.SignatureCache.Hits',
		'Database.NSF.SignatureCache.Tries',
		'Database.NSF.UNKS.MemorySaved',
		'Database.NSF.UNKS.MemoryUsed',
		'Database.NSF.UNKS.Shared',
		'Database.NSF.UNKS.Total',
		'Database.RM.Sys.Logged',
		'Disk.C.Free',
		'Disk.C.Size',
		'Disk.C.Type',
		'Disk.D.Free',
		'Disk.D.Size',
		'Disk.D.Type',
		'Disk.Fixed',
		'Disk.G.Free',
		'Disk.G.Size',
		'Disk.G.Type',
		'Disk.Remote',
		'Domino.Cache.Command.Count',
		'Domino.Cache.Command.DisplaceRate',
		'Domino.Cache.Command.HitRate',
		'Domino.Cache.Command.MaxSize',
		'Domino.Cache.Design.Count',
		'Domino.Cache.Design.DisplaceRate',
		'Domino.Cache.Design.HitRate',
		'Domino.Cache.Design.MaxSize',
		'Domino.Cache.Forms View Summary.Count',
 		'Domino.Cache.Forms View Summary.DisplaceRate',
		'Domino.Cache.Forms View Summary.HitRate',
		'Domino.Cache.FormsCache.Count',
		'Domino.Cache.FormsCache.MaxSize',
		'Domino.Cache.iNote WA Forms file.Count',
		'Domino.Cache.NNotesID.Count',
		'Domino.Cache.NNotesID.DisplaceRate',
		'Domino.Cache.NNotesID.HitRate',
		'Domino.Cache.NNotesID.MaxSize',
		'Domino.Cache.Note Cache.HitRate',
		'Domino.Cache.Session Cache.Count',
		'Domino.Cache.Session Cache.MaxSize',
		'Domino.Cache.Shimmer Profile Cache.Count',
		'Domino.Cache.SkinGroupsCache.Count',
		'Domino.Cache.SkinGroupsCache.MaxSize',
		'Domino.Cache.SubformsCache.Count',
		'Domino.Cache.SubformsCache.MaxSize',
		'Domino.Cache.User Cache.Count',
		'Domino.Cache.User Cache.DisplaceRate',
		'Domino.Cache.User Cache.HitRate',
		'Domino.Cache.User Cache.MaxSize',
		'Domino.Command.CopyToFolder',
		'Domino.Command.CreateDocument',
		'Domino.Command.DeleteDocument',
		'Domino.Command.DeleteDocuments',
		'Domino.Command.EditDocument',
		'Domino.Command.GetOrbCookie',
		'Domino.Command.MoveToFolder',
		'Domino.Command.Navigate',
		'Domino.Command.OpenAbout',
		'Domino.Command.OpenAgent',
		'Domino.Command.OpenCssResource',
		'Domino.Command.OpenDatabase',
		'Domino.Command.OpenDocument',
		'Domino.Command.OpenElement',
		'Domino.Command.OpenFileResource',
		'Domino.Command.OpenForm',
		'Domino.Command.OpenHelp',
		'Domino.Command.OpenIcon',
		'Domino.Command.OpenImageResource',
		'Domino.Command.OpenJavascriptLib',
		'Domino.Command.OpenNavigator',
		'Domino.Command.OpenPreferences',
		'Domino.Command.OpenServer',
		'Domino.Command.OpenView',
		'Domino.Command.OpenWebService',
		'Domino.Command.ReadForm',
		'Domino.Command.Redirect',
		'Domino.Command.RemoveFromFolder',
		'Domino.Command.RequestCert',
		'Domino.Command.SaveDocument',
		'Domino.Command.SearchDomain',
		'Domino.Command.SearchSite',
		'Domino.Command.SearchView',
		'Domino.Command.Total',
		'Domino.Command.Unknown',
		'Domino.Command.WSDL',
		'Domino.Config.ActiveThreads.Max',
		'Domino.Config.ActiveThreads.Min',
		'Domino.Config.AllowDirectoryLinks',
		'Domino.Config.Directory.CGI',
		'Domino.Config.Directory.HTML',
		'Domino.Config.Directory.Icons',
		'Domino.Config.Directory.JavaRoot',
		'Domino.Config.DNSLookup',
		'Domino.Config.EnforceAccess',
		'Domino.Config.HomeURL',
		'Domino.Config.HostName',
		'Domino.Config.Image.Format',
		'Domino.Config.Image.Interlaced',
		'Domino.Config.Log.Access',
		'Domino.Config.Log.Error',
		'Domino.Config.Log.Filter',
		'Domino.Config.Log.TimeStamp',
		'Domino.Config.PortNumber',
		'Domino.Config.PortStatus',
		'Domino.Config.SSL.KeyFile',
		'Domino.Config.SSL.PortNumber',
		'Domino.Config.SSL.Status',
		'Domino.Config.Timeout.CGI',
		'Domino.Config.Timeout.IdleThread',
		'Domino.Config.Timeout.Input',
		'Domino.Config.Timeout.Output',
		'Domino.Config.URLpath.CGI',
		'Domino.Config.URLpath.Icons',
		'Domino.Config.URLpath.JavaRoot',
		'Domino.Config.URLpath.Servlet',
		'Domino.Config.View.Lines',
		'Domino.Config.WelcomePage',
		'Domino.Requests.Per1Day.Peak',
		'Domino.Requests.Per1Day.PeakTime',
		'Domino.Requests.Per1Day.Total',
		'Domino.Requests.Per1Hour.Peak',
		'Domino.Requests.Per1Hour.PeakTime',
		'Domino.Requests.Per1Hour.Total',
		'Domino.Requests.Per1Minute.Peak',
		'Domino.Requests.Per1Minute.PeakTime',
		'Domino.Requests.Per1Minute.Total',
		'Domino.Requests.Per5Minute.Peak',
		'Domino.Requests.Per5Minute.PeakTime',
		'Domino.Requests.Per5Minute.Total',
		'Domino.Requests.Total',
		'Domino.ThreadPool.average',
		'Domino.ThreadPool.max',
		'Domino.Threads.Active.Peak',
		'EVENT.EventDispatcher.Queue.Entries',
		'EVENT.EventDispatcher.Queue.MaxEntries',
		'EVENT.EventDispatcher.Queue.TotalEntries',
		'EVENT.EVENTLOG.Queue.Entries',
		'EVENT.EVENTLOG.Queue.MaxEntries',
		'EVENT.EVENTLOG.Queue.TotalEntries',
		'EVENT.LOG.Queue.Entries',
		'EVENT.Log.Queue.MaxEntries',
		'EVENT.Log.Queue.TotalEntries',
		'EVENT.MaxEventPoolSize',
		'EVENT.MsgCache.Time.Empty',
		'EVENT.PROBEMGR.Queue.Entries',
		'EVENT.PROBEMGR.Queue.MaxEntries',
		'EVENT.PROBEMGR.Queue.TotalEntries',
		'FT.Index.Bytes.PerHour',
		'FT.Index.Count',
		'FT.Index.Documents.Added',
		'FT.Index.Documents.Deleted',
		'FT.Index.Documents.Updated',
		'FT.Index.Total.Bytes',
		'FT.Index.Total.TimeMS',
		'FT.Search.Average.TimeMS',
		'FT.Search.Count',
		'FT.Search.Max.ActualHits',
		'FT.Search.Max.Results',
		'FT.Search.Open',
		'FT.Search.Results.Zero',
		'FT.Search.Total.ActualHits',
		'FT.Search.Total.Results',
		'FT.Search.Total.TimeMS',
		'Http.Accept.ConnectionsAccepted',
		'Http.Accept.ConnectionsDenied',
		'Http.Accept.ConnectionsRefused',
		'Http.Accept.Errors',
		'Http.Accept.Polls',
		'Http.Accept.PollTimeouts',
		'Http.Accept.ServerBusy',
		'Http.CurrentConnections',
		'Http.JavaCache.Enabled',
		'Http.JavaCache.Entries.Current',
		'Http.JavaCache.Entries.Maximum',
		'Http.JavaCache.Prune.Run.Interval',
		'Http.JavaCache.Prune.Run.Next',
		'Http.JavaCache.Prune.Time.Locked.Avg',
		'Http.JavaCache.Prune.Time.Locked.Max',
		'Http.JavaCache.Prune.Time.Locked.Min',
		'Http.JavaCache.Prune.Time.Total.Avg',
		'Http.JavaCache.Prune.Time.Total.Max',
		'Http.JavaCache.Prune.Time.Total.Min',
		'Http.JavaCache.Size.Current',
		'Http.JavaCache.Size.Maximum',
		'Http.JavaCache.Total.Adds',
		'Http.JavaCache.Total.Adds.Missed',
		'Http.JavaCache.Total.Errors',
		'Http.JavaCache.Total.Hits',
		'Http.JavaCache.Total.Misses',
		'Http.MaxConnections',
		'Http.PeakConnections',
		'Http.Workers',
		'Http.Worker.Total.BytesRead',
		'Http.Worker.Total.BytesWritten',
		'Http.Worker.Total.Cgi.Requests',
		'Http.Worker.Total.Cgi.RequestTime',
		'Http.Worker.Total.DomWS.Requests',
		'Http.Worker.Total.DomWS.RequestTime',
		'Http.Worker.Total.Dsapi.Requests',
		'Http.Worker.Total.Dsapi.RequestTime',
		'Http.Worker.Total.File.Requests',
		'Http.Worker.Total.File.RequestTime',
		'Http.Worker.Total.Http.Requests',
		'Http.Worker.Total.Http.RequestTime',
		'Http.Worker.Total.IdleSessionTimeouts',
		'Http.Worker.Total.InputTimeouts',
		'Http.Worker.Total.Notes.Requests',
		'Http.Worker.Total.Notes.RequestTime',
		'Http.Worker.Total.OutputTimeouts',
		'Http.Worker.Total.QuickPlace.Requests',
		'Http.Worker.Total.QuickPlace.RequestTime',
		'Http.Worker.Total.RequestsProcessed',
		'Http.Worker.Total.TotalRequestTime',
		'IMAP.Server.Running',
		'IMAP.Sessions.Inbound.Accept.Queue',
		'IMAP.Sessions.Inbound.Active',
		'IMAP.Sessions.Inbound.Active.SSL',
		'IMAP.Sessions.Inbound.BytesReceived',
		'IMAP.Sessions.Inbound.BytesSent',
		'IMAP.Sessions.Inbound.Peak',
		'IMAP.Sessions.Inbound.Peak.SSL',
		'IMAP.Sessions.Inbound.Total',
		'IMAP.Sessions.Inbound.Total.SSL',
		'IMAP.Sessions.Inbound.Total.SSL.Bad_Handshake',
		'IMAP.Sessions.Threads.Busy',
		'IMAP.Sessions.Threads.Idle',
		'IMAP.Sessions.Threads.InThreadPool',
		'IMAP.Sessions.Threads.Peak',
		'IMAP.TotalMsgCached',
		'IMAP.WorkerThreadPool.ConvertThreads.Total',
		'IMAP.WorkerThreadPool.CopyThreads.Total',
		'IMAP.WorkerThreadPool.FetchThreads.Max',
		'IMAP.WorkerThreadPool.FetchThreads.Total',
		'IMAP.WorkerThreadPool.ResponseThreads.Max',
		'IMAP.WorkerThreadPool.ResponseThreads.MaxPerFetch',
		'IMAP.WorkerThreadPool.ResponseThreads.Total',
		'IMAP.WorkerThreadPool.Threads.Idle',
		'IMAP.WorkerThreadPool.Threads.Max',
		'IMAP.WorkerThreadPool.Threads.Total',
		'LDAP.Server.Running',
		'LDAP.Sessions.Inbound.Accept.Queue',
		'LDAP.Sessions.Inbound.Active',
		'LDAP.Sessions.Inbound.Active.SSL',
		'LDAP.Sessions.Inbound.BytesReceived',
		'LDAP.Sessions.Inbound.BytesSent',
		'LDAP.Sessions.Inbound.Peak',
		'LDAP.Sessions.Inbound.Peak.SSL',
		'LDAP.Sessions.Inbound.Total',
		'LDAP.Sessions.Inbound.Total.SSL',
		'LDAP.Sessions.Inbound.Total.SSL.Bad_Handshake',
		'LDAP.Sessions.Threads.Busy',
		'LDAP.Sessions.Threads.Idle',
		'LDAP.Sessions.Threads.InThreadPool',
		'LDAP.Sessions.Threads.Peak',
		'Mail.AverageDeliverTime',
		'Mail.AverageServerHops',
		'Mail.AverageSizeDelivered',
		'Mail.CurrentByteDeliveryRate',
		'Mail.CurrentByteTransferRate',
		'Mail.CurrentMessageDeliveryRate',
		'Mail.CurrentMessageTransferRate',
		'Mail.DBCacheAged',
		'Mail.DBCacheEntries',
		'Mail.DBCacheForcedOut',
		'Mail.DBCacheHighWaterMark',
		'Mail.DBCacheHits',
		'Mail.DBCacheMaxEntries',
		'Mail.DBCacheReads',
		'MAIL.Dead',
		'Mail.Delivered',
		'Mail.DeliveredSize.100KB_to_1MB',
		'Mail.DeliveredSize.10KB_to_100KB',
		'Mail.DeliveredSize.1KB_to_10KB',
		'Mail.DeliveredSize.1MB_to_10MB',
		'Mail.DeliveredSize.Under_1KB',
		'Mail.Deliveries',
		'Mail.DeliveryThreads.Active',
		'Mail.DeliveryThreads.Max',
		'Mail.DeliveryThreads.Total',
		'Mail.Domain',
		'MAIL.Hold',
		'Mail.Mailbox.AccessConflicts',
		'Mail.Mailbox.Accesses',
		'Mail.Mailbox.AccessWarnings',
		'Mail.Mailbox.CurrentAccesses',
		'Mail.Mailbox.MaxConcurrentAccesses',
		'Mail.Mailbox.Opens',
		'Mail.MaximumDeliverTime',
		'Mail.MaximumServerHops',
		'Mail.MaximumSizeDelivered',
		'Mail.MinimumDeliverTime',
		'Mail.MinimumServerHops',
		'Mail.MinimumSizeDelivered',
		'Mail.PeakByteDeliveryRate',
		'Mail.PeakByteTransferRate',
		'Mail.PeakMessageDeliveryRate',
		'Mail.PeakMessageDeliveryTime',
		'Mail.PeakMessagesDelivered',
		'Mail.PeakMessagesTransferred',
		'Mail.PeakMessageTransferRate',
		'Mail.PeakMessageTransferTime',
		'Mail.PeakTotalBytesDelivered',
		'Mail.PeakTotalBytesTransferred',
		'MAIL.TotalFailures',
		'Mail.TotalKBDelivered',
		'Mail.TotalKBTransferred',
		'Mail.TotalKBTransferred.SMTP',
		'Mail.TotalPending',
		'Mail.TotalRouted',
		'Mail.TotalRouted.NRPC',
		'Mail.TotalRouted.SMTP',
		'Mail.TransferFailures',
		'Mail.TransferFailures.SMTP',
		'Mail.Transferred',
		'Mail.TransferredSize.100KB_to_1MB',
		'Mail.TransferredSize.10KB_to_100KB',
		'Mail.TransferredSize.1KB_to_10KB',
		'Mail.TransferredSize.1MB_to_10MB',
		'Mail.TransferredSize.Under_1KB',
		'Mail.Transferred.SMTP',
		'Mail.TransferThreads.Active',
		'Mail.TransferThreads.Concurrent.Highest',
		'Mail.TransferThreads.Concurrent.Max',
		'Mail.TransferThreads.Max',
		'Mail.TransferThreads.Total',
		'MAIL.Waiting',
		'Mail.WaitingForDeliveryRetry',
		'MAIL.WaitingForDIR',		
		'MAIL.WaitingForDNS',
		'MAIL.WaitingRecipients',
		'Mem.Allocated',
		'Mem.Allocated.Process',
		'Mem.Allocated.Shared',
		'Mem.Availability',
		'Mem.Free',
		'Mem.MaxAddressableMemory_MB',
		'Mem.MaxSharedMemory_MB',
		'Mem.PhysicalRAM',
		'Mem.PhysicalRAM_MB',
		'Mem.Reallocs.Down',
		'Mem.Reallocs.Same',
		'Mem.Reallocs.Up',
		'Monitor.ADMIN PROCESS.Failure',
		'Monitor.AGENT MANAGER.Warning(High)',
		'Monitor.DATABASE COMPACTOR.Failure',
		'Monitor.DATABASE COMPACTOR.Fatal',
		'Monitor.EVENT MONITOR.Warning(High)',
		'Monitor.INDEXER.Warning(High)',
		'Monitor.Last.ADMIN PROCESS.Failure',
		'Monitor.Last.ADMIN PROCESS.FailureText',
		'Monitor.Last.AGENT MANAGER.Warning(High)',
		'Monitor.Last.AGENT MANAGER.Warning(High)Text',
		'Monitor.Last.DATABASE COMPACTOR.Failure',
		'Monitor.Last.DATABASE COMPACTOR.FailureText',
		'Monitor.Last.DATABASE COMPACTOR.Fatal',
		'Monitor.Last.DATABASE COMPACTOR.FatalText',
		'Monitor.Last.DATABASE COMPACTOR.Warning(High)Text',
		'Monitor.Last.EVENT MONITOR.Warning(High)',
		'Monitor.Last.EVENT MONITOR.Warning(High)Text',
		'Monitor.Last.INDEXER.Warning(High)',
		'Monitor.Last.ROUTER.Failure',
		'Monitor.Last.ROUTER.FailureText',
		'Monitor.Last.ROUTER.Warning(High)',
		'Monitor.Last.ROUTER.Warning(High)Text',
		'Monitor.Last.SCHEDULE MANAGER.Failure',
		'Monitor.Last.SCHEDULE MANAGER.FailureText',
		'Monitor.Last.SCHEDULE MANAGER.Warning(High)',
		'Monitor.Last.SCHEDULE MANAGER.Warning(High)Text',
		'Monitor.Last.Server.Failure',
		'Monitor.Last.Server.FailureText',
		'Monitor.Last.Server.Warning(High)',
		'Monitor.Last.Server.Warning(High)Text',
		'Monitor.ROUTER.Failure',
		'Monitor.ROUTER.Warning(High)',
		'Monitor.SCHEDULE MANAGER.Failure',
		'Monitor.SCHEDULE MANAGER.Warning(High)',
		'Monitor.Server.Failure',
		'Monitor.Server.Warning(High)',
		'NET.Cluster.BytesReceived',
		'NET.Cluster.BytesSent',
		'NET.Cluster.Sessions.Established.Incoming',
		'NET.Cluster.Sessions.Established.Outgoing',
		'NET.Cluster.Sessions.Limit',
		'NET.Cluster.Sessions.LimitMax',
		'NET.Cluster.Sessions.LimitMin',
		'NET.Cluster.Sessions.Peak',
		'NET.Cluster.Sessions.Recycled',
		'NET.Cluster.Sessions.Recycling',
		'NET.GroupCache.Hits',
		'NET.GroupCache.Misses',
		'NET.GroupCache.NumEntries',
		'NET.GroupCache.Size',
		'NET.GroupCache.Used',
		'NET.ICM.BytesReceived',
		'NET.ICM.BytesSent',
		'NET.ICM.Sessions.Established.Incoming',
		'NET.ICM.Sessions.Established.Outgoing',
		'NET.ICM.Sessions.Limit',
		'NET.ICM.Sessions.LimitMax',
		'NET.ICM.Sessions.LimitMin',
		'NET.ICM.Sessions.Peak',
		'NET.ICM.Sessions.Recycled',
		'NET.ICM.Sessions.Recycling',
		'NET.Log.ServNotes2/TractebelEnergia.PeakUnwrittenEntries',
		'NET.Log.ServNotes2/TractebelEnergia.UnwrittenEntries',
		'NET.Sessions.DeferredClosed.Current',
		'NET.Sessions.DeferredClosed.Peak',
		'NET.TCPIP.BytesReceived',
		'NET.TCPIP.BytesSent',
		'NET.TCPIP.Sessions.Established.Incoming',
		'NET.TCPIP.Sessions.Established.Outgoing',
		'NET.TCPIP.Sessions.Limit',
		'NET.TCPIP.Sessions.LimitMax',
		'NET.TCPIP.Sessions.LimitMin',
		'NET.TCPIP.Sessions.Peak',
		'NET.TCPIP.Sessions.Recycled',
		'NET.TCPIP.Sessions.Recycling',
		'Platform.ActiveNumOfDominoPartitions',
		'Platform.LogicalDisk.1.AssignedName',
		'Platform.LogicalDisk.1.AvgQueueLen',
		'Platform.LogicalDisk.1.AvgQueueLen.Avg',
		'Platform.LogicalDisk.1.AvgQueueLen.Peak',
		'Platform.LogicalDisk.1.PctUtil',
		'Platform.LogicalDisk.1.PctUtil.Avg',
		'Platform.LogicalDisk.1.PctUtil.Peak',
		'Platform.LogicalDisk.2.AssignedName',
		'Platform.LogicalDisk.2.AvgQueueLen',
		'Platform.LogicalDisk.2.AvgQueueLen.Avg',
		'Platform.LogicalDisk.2.AvgQueueLen.Peak',
		'Platform.LogicalDisk.2.PctUtil',
		'Platform.LogicalDisk.2.PctUtil.Avg',
		'Platform.LogicalDisk.2.PctUtil.Peak',
		'Platform.LogicalDisk.3.AssignedName',
		'Platform.LogicalDisk.3.AvgQueueLen',
		'Platform.LogicalDisk.3.AvgQueueLen.Avg',
		'Platform.LogicalDisk.3.AvgQueueLen.Peak',
		'Platform.LogicalDisk.3.PctUtil',
		'Platform.LogicalDisk.3.PctUtil.Avg',
		'Platform.LogicalDisk.3.PctUtil.Peak',
		'Platform.LogicalDisk.TotalNumofDisks',
		'Platform.Memory.PagesPerSec',
		'Platform.Memory.PagesPerSec.Avg',
		'Platform.Memory.PagesPerSec.Peak',
		'Platform.Memory.RAM.AvailMBytes',
		'Platform.Memory.RAM.AvailMBytes.Avg',
		'Platform.Memory.RAM.AvailMBytes.Min',
		'Platform.Memory.RAM.AvailMBytes.Peak',
		'Platform.Memory.RAM.PctUtil',
		'Platform.Memory.RAM.TotalMBytes',
		'Platform.Network.1.AdapterName',
		'Platform.Network.1.BytesRecvdPerSec',
		'Platform.Network.1.BytesSentPerSec',
		'Platform.Network.1.CurrBandwidthMbitsPerSec',
		'Platform.Network.1.PctUtilBandwidth',
		'Platform.Network.1.TotalBytesPerSec',
		'Platform.Network.2.AdapterName',
		'Platform.Network.2.BytesRecvdPerSec',
		'Platform.Network.2.BytesSentPerSec',
		'Platform.Network.2.CurrBandwidthMbitsPerSec',
		'Platform.Network.2.PctUtilBandwidth',
		'Platform.Network.2.TotalBytesPerSec',
		'Platform.Network.3.AdapterName',
		'Platform.Network.3.BytesRecvdPerSec',
		'Platform.Network.3.BytesSentPerSec',
		'Platform.Network.3.CurrBandwidthMbitsPerSec',
		'Platform.Network.3.PctUtilBandwidth',
		'Platform.Network.3.TotalBytesPerSec',
		'Platform.Network.TotalNumofAdapters',
		'Platform.Network.Total.BytesRecvdPerSec',
		'Platform.Network.Total.BytesSentPerSec',
		'Platform.Network.Total.CurrBandwidthMbitsPerSec',
		'Platform.Network.Total.NetworkBytesPerSec',
		'Platform.Network.Total.PctUtilBandwidth',
		'Platform.PagingFile.Total.PctUtil',
		'Platform.PagingFile.Total.PctUtil.Avg',
		'Platform.PagingFile.Total.PctUtil.Peak',
		'Platform.Process.ActiveDomino.TotalCpuUtil',
		'Platform.Process.ActiveNumOfDominoProc',
		'Platform.Process.adminp.1.PctCpuUtil',
		'Platform.Process.adminp.1.ProcessID',
		'Platform.Process.amgr.1.PctCpuUtil',
		'Platform.Process.amgr.1.ProcessID',
		'Platform.Process.amgr.2.PctCpuUtil',
		'Platform.Process.amgr.2.ProcessID',
		'Platform.Process.amgr.3.PctCpuUtil',
		'Platform.Process.amgr.3.ProcessID',
		'Platform.Process.calconn.1.PctCpuUtil',
		'Platform.Process.calconn.1.ProcessID',		
		'Platform.Process.cldbdir.1.PctCpuUtil',
		'Platform.Process.cldbdir.1.ProcessID',
		'Platform.Process.clrepl.1.PctCpuUtil',
		'Platform.Process.clrepl.1.ProcessID',
		'Platform.Process.clrepl.2.PctCpuUtil',
		'Platform.Process.clrepl.2.ProcessID',
		'Platform.Process.clrepl.3.PctCpuUtil',
		'Platform.Process.clrepl.3.ProcessID',
		'Platform.Process.collect.1.PctCpuUtil',
		'Platform.Process.collect.1.ProcessID',
		'Platform.Process.decs.1.PctCpuUtil',
		'Platform.Process.decs.1.ProcessID',
		'Platform.Process.dircat.1.PctCpuUtil',
		'Platform.Process.dircat.1.ProcessID',
		'Platform.Process.entitymain.1.PctCpuUtil',
		'Platform.Process.entitymain.1.ProcessID',
		'Platform.Process.event.1.PctCpuUtil',
		'Platform.Process.event.1.ProcessID',
		'Platform.Process.http.1.PctCpuUtil',
		'Platform.Process.http.1.ProcessID',
		'Platform.Process.imap.1.PctCpuUtil',
		'Platform.Process.imap.1.ProcessID',
		'Platform.Process.intrcpt.1.PctCpuUtil',
		'Platform.Process.intrcpt.1.ProcessID',
		'Platform.Process.ldap.1.PctCpuUtil',
		'Platform.Process.ldap.1.ProcessID',
		'Platform.Process.maps.1.PctCpuUtil',
		'Platform.Process.maps.1.ProcessID',
		'Platform.Process.mtc.1.PctCpuUtil',
		'Platform.Process.mtc.1.ProcessID',
		'Platform.Process.procmon.1.PctCpuUtil',
		'Platform.Process.procmon.1.ProcessID',
		'Platform.Process.quryset.1.PctCpuUtil',
		'Platform.Process.quryset.1.ProcessID',
		'Platform.Process.replica.1.PctCpuUtil',
		'Platform.Process.replica.1.ProcessID',
		'Platform.Process.rnrmgr.1.PctCpuUtil',
		'Platform.Process.rnrmgr.1.ProcessID',
		'Platform.Process.router.1.PctCpuUtil',
		'Platform.Process.router.1.ProcessID',
		'Platform.Process.sched.1.PctCpuUtil',
		'Platform.Process.sched.1.ProcessID',
		'Platform.Process.server.1.PctCpuUtil',
		'Platform.Process.server.1.ProcessID',
		'Platform.Process.smdemf.1.PctCpuUtil',
		'Platform.Process.smdemf.1.ProcessID',
		'Platform.Process.smdmon.1.PctCpuUtil',
		'Platform.Process.smdmon.1.ProcessID',
		'Platform.Process.smdreal.1.PctCpuUtil',
		'Platform.Process.smdreal.1.ProcessID',
		'Platform.Process.smdsch.1.PctCpuUtil',
		'Platform.Process.smdsch.1.ProcessID',
		'Platform.Process.smtp.1.PctCpuUtil',
		'Platform.Process.smtp.1.ProcessID',
		'Platform.Process.update.1.PctCpuUtil',
		'Platform.Process.update.1.ProcessID',
		'Platform.System.ContextSwitchesPerSec',
		'Platform.System.ContextSwitchesPerSec.Avg',
		'Platform.System.ContextSwitchesPerSec.Min',
		'Platform.System.ContextSwitchesPerSec.Peak',
		'Platform.System.PctCombinedCpuUtil',
		'Platform.System.PctCombinedCpuUtil.Avg',
		'Platform.System.PctCombinedCpuUtil.Peak',
		'Platform.System.PctTotalPrivilegedCpuUtil',
		'Platform.System.PctTotalPrivilegedCpuUtil.Avg',
		'Platform.System.PctTotalPrivilegedCpuUtil.Peak',
		'Platform.System.PctTotalUserCpuUtil',
		'Platform.System.PctTotalUserCpuUtil.Avg',
		'Platform.System.PctTotalUserCpuUtil.Peak',
		'Platform.Time.LastSample',
		'Platform.Time.SampleRateInMins',
		'Replica.Cluster.Docs.Added',
		'Replica.Cluster.Docs.Deleted',
		'Replica.Cluster.Docs.Updated',
		'Replica.Cluster.Failed',
		'Replica.Cluster.Files.Local',
		'Replica.Cluster.Files.Remote',
		'Replica.Cluster.Retry.Skipped',
		'Replica.Cluster.Retry.Waiting',
		'Replica.Cluster.SecondsOnQueue',
		'Replica.Cluster.SecondsOnQueue.Avg',
		'Replica.Cluster.SecondsOnQueue.Max',
		'Replica.Cluster.Servers',
		'Replica.Cluster.SessionBytes.In',
		'Replica.Cluster.SessionBytes.Out',
		'Replica.Cluster.Successful',
		'Replica.Cluster.WorkQueueDepth',
		'Replica.Cluster.WorkQueueDepth.Avg',
		'Replica.Cluster.WorkQueueDepth.Max',
		'Replica.Docs.Added',
		'Replica.Docs.Deleted',
		'Replica.Docs.Updated',
		'Replica.Successful',
		'Sem.Timeouts',
		'Server.Administrators',
		'Server.Administrators.Access',
		'Server.Administrators.FullAccess',
		'Server.AvailabilityIndex',
		'Server.AvailabilityThreshold',
		'Server.BootID',
		'Server.Cluster.Member.ServContingencia/TractebelEnergia.Index',
		'Server.Cluster.Member.ServContingencia/TractebelEnergia.NumericIndex',
		'Server.Cluster.Member.ServNotes1/TractebelEnergia.Index',
		'Server.Cluster.Member.ServNotes1/TractebelEnergia.NumericIndex',
		'Server.Cluster.Member.ServNotes2/TractebelEnergia.Index',
		'Server.Cluster.Member.ServNotes2/TractebelEnergia.NumericIndex',
		'Server.Cluster.Name',
		'Server.Cluster.OpenRedirects.FailoverByPath.Successful',
		'Server.Cluster.OpenRedirects.FailoverByPath.Unsuccessful',
		'Server.Cluster.OpenRedirects.Failover.Successful',
		'Server.Cluster.OpenRedirects.Failover.Unsuccessful',
		'Server.Cluster.OpenRedirects.LoadBalanceByPath.Successful',
		'Server.Cluster.OpenRedirects.LoadBalanceByPath.Unsuccessful',
		'Server.Cluster.OpenRedirects.LoadBalance.Successful',
		'Server.Cluster.OpenRedirects.LoadBalance.Unsuccessful',
		'Server.Cluster.OpenRequest.ClusterBusy',
		'Server.Cluster.OpenRequest.DatabaseOutOfService',
		'Server.Cluster.OpenRequest.LoadBalanced',
		'Server.Cluster.PortName',
		'Server.Cluster.ProbeCount',
		'Server.Cluster.ProbeError',
		'Server.Cluster.ProbeTimeout(mins)',
		'Server.ConcurrentTasks',
		'Server.ConcurrentTasks.Max',
		'Server.ConcurrentTasks.Waiting',
		'Server.CPU.Count',
		'Server.CPU.Type',
		'Server.ElapsedTime',
		'Server.ExpansionFactor',
		'Server.MailBoxes',
		'Server.Monitor.Start',
		'Server.Name',
		'Server.Path.Configfile',
		'Server.Path.Data',
		'Server.Path.Executable',
		'Server.Ports',
		'Server.PoweredBy',
		'Server.Sessions.Dropped',
		'Server.SharedMail',
		'Server.Tasks',
		'Server.Task.DB',
		'Server.Time.Start',
		'Server.Title',
		'Server.Trans.PerMinute',
		'Server.Trans.PerMinute.Peak',
		'Server.Trans.PerMinute.Peak.Time',
		'Server.Trans.Total',
		'Server.Users',
		'Server.Users.1MinPeak',
		'Server.Users.1MinPeakTime',
		'Server.Users.5MinPeak',
		'Server.Users.5MinPeakTime',
		'Server.Users.Active',
		'Server.Users.Active15Min',
		'Server.Users.Active1Min',
		'Server.Users.Active30Min',
		'Server.Users.Active3Min',
		'Server.Users.Active5Min',
		'Server.Users.Peak',
		'Server.Users.Peak.Time',
		'Server.Version.Notes',
		'Server.Version.Notes.BuildNumber',
		'Server.Version.OS',
		'Server.WorkThreads',
		'SMD.Current.ScanEngineVersion',
		'SMD.Current.Version',
		'SMD.Current.VirusPatternVersion',
		'SMD.Mail.AmountMails',
		'SMD.Mail.BlockedMails',
		'SMD.Mail.ScannedAmount',
		'SMD.Mail.ScannedFiles',
		'SMTP.Command.DATA',
		'SMTP.Command.EHLO',
		'SMTP.Command.HELO',
		'SMTP.Command.MAIL',
		'SMTP.Command.QUIT',
		'SMTP.Command.RCPT',
		'SMTP.Command.RSET',
		'SMTP.MessagesProcessed',
		'SMTP.MsgRecipients.Ave',
		'SMTP.MsgRecipients.Max',
		'SMTP.MsgRecipients.Min',
		'SMTP.MsgRecipients.Total',
		'SMTP.MsgSizeKBytes.Ave',
		'SMTP.MsgSizeKBytes.Max',
		'SMTP.MsgSizeKBytes.Min',
		'SMTP.MsgSizeKBytes.Total',
		'SMTP.Server.Running',
		'SMTP.SessionDuration.0Sec_to_5Sec',
		'SMTP.SessionDuration.10Sec_to_15Sec',
		'SMTP.SessionDuration.15Sec_to_20Sec',
		'SMTP.SessionDuration.20Sec_to_25Sec',
		'SMTP.SessionDuration.50Sec_to_55Sec',
		'SMTP.SessionDuration.5Sec_to_10Sec',
		'SMTP.SessionDuration.Above_60Sec',
		'SMTP.SessionDuration.Max',
		'SMTP.SessionDuration.Min',
		'SMTP.Sessions.Inbound.Accept.Queue',
		'SMTP.Sessions.Inbound.Active',
		'SMTP.Sessions.Inbound.Active.SSL',
		'SMTP.Sessions.Inbound.BytesReceived',
		'SMTP.Sessions.Inbound.BytesSent',
		'SMTP.Sessions.Inbound.Peak',
		'SMTP.Sessions.Inbound.Peak.SSL',
		'SMTP.Sessions.Inbound.Total',
		'SMTP.Sessions.Inbound.Total.SSL',
		'SMTP.Sessions.Inbound.Total.SSL.Bad_Handshake',
		'SMTP.Sessions.Threads.Busy',
		'SMTP.Sessions.Threads.Idle',
		'SMTP.Sessions.Threads.InThreadPool',
		'SMTP.Sessions.Threads.Peak',
		'Stats.Time.Current',
		'Stats.Time.Start',
		'Update.DeferredList',
		'Update.DeferredList.Duplicates',
		'Update.DeferredList.Max',
		'Update.DeferredList.NextDueTime',
		'Update.DeferredList.Processed.AllViews',
		'Update.DeferredList.Processed.FullText',
		'Update.NAB.Updates',
		'Update.PendingList',
		'Update.PendingList.Duplicates',
		'Update.PendingList.Max',
		'Update.PendingList.Processed.AllViews',
		'Update.PendingList.Processed.FullText',
		'Update.PendingList.Processed.SingleView',
);

sub count_options {

	my $c = 0;
	my @matched;
	foreach (@validvalues) {
		if ($_ =~ /$opt_opt/) {
			push(@matched,$_);
			$c++;
		}
	}

	if ($c > 1 ) {
		print "UNKNOWN - Multiplas opcoes para $opt_opt: @matched\n";
		exit(3);
	} 

}

&main;
