#!/usr/bin/php -q
<?php

/*******************************************************************************
* Header
********************************************************************************

TICKET: <numero do ticket no OpDesk>
AUTOR: Josiane Tarasconi
CRIADO EM: 08/01/2016 14:00:00

REVISÕES:
--------------------------------------------------------------
<versão> <Data da Revisão>, <autor da revisao>
    - <Descrição das modificações>

********************************************************************************/

require_once '/usr/local/opmon/etc/config.php';
require_once '/usr/local/opmon/libexec/php-nagios-plugins/Nagios_Plugin.php';

define("VERSION", "1.0");

$np = null;
/*******************************************************************************
* Exibi o manual do software
********************************************************************************/
function getGuideLine()
{
	print <<<EOF

------------------------------------------
Manual
------------------------------------------

Descrição do plugin:
	Este plugin exibe a quantidade de trafégo que está passando em
    um determinado IP do Top 10, passado por parâmetro.

Instalação:
	Este plugin esta na imagem do OpMon.

Dependências:
	php-nagios-plugins
	yum install php-nagios-plugins -y

Funcionamento:
	Basta inserir no monitoramento e informar qual a o IP que deseja verificar, a unidade de medida
    (KB ou MB) e os parâmetros de warning e critical.

Exemplos de execução e retorno do comando:
    ./check_traffic_ip -H 127.0.0.1 --ip 127.0.0.1 -u kb -w 2 -c 3
   		Traffic from 192.168.10.144 is 0KB | traffic=0KB;2;3;0;

EOF;

	exit(OK);

}
/*******************************************************************************
* Seta os atributos da variável global $np
********************************************************************************/

function set_nagios() {

  global $np;

  $np = new Nagios_Plugin(
      array(
        'version' => VERSION . " [kb.opservices.com.br]",
        'blurb' => "Developed by:\n\tOpServices\n"
                 . "Author: \nJosiane Tarasconi - josiane.tarasconi\@opservices.com.br\n",
        'usage' => "Usage:\n\t%s -H <hostname> --ip 127.0.0.1 -u < kb | mb > \n"
                 ." \t -w <warning in KB or MB> -c <critical in KB or MB> "
      )
  );

  $np->add_arg("hostname|H=s", "Hostname");
  $np->add_arg("ip=s", "IP for traffic");
  $np->add_arg("unity|u=s", "MB or KB");
  $np->add_arg("warning|w=i", "Warning parameters");
  $np->add_arg("critical|c=i", "Critical parameters");
  $np->add_arg("man|m=s", "Show Manual");

  $np->getopts();
}

function metric($size, $warning, $critical){

    if ($size >= $critical){
      return 2;
    }
    if ($size >= $warning){
      return 1;
    } else {
      return 0;
    }
}

function main() {

  global $np;

  set_nagios();

  if (isset($np->opts['man'])) {
		getGuideLine();
	}

  if (isset($np->opts['hostname'])){
    $host = $np->opts['hostname'];
  } else {
	   $host = "localhost";
  }

  $url = sprintf(
      'https://%s/opmon/seagull/www/index.php/traffic/action/filter/',
      $host
  );

  $data = array(
  		 'group_by'     => 'ip_src',
  		 'resolve_name' => true,
  	 	);
  $params = array('action' => 'filter','jsonData' => json_encode($data));
  $r = http_request($url,$params);
  $a = json_decode($r);

  $regex = preg_split("/[\s,]+/",$np->opts['ip']);

  #print_r($a);


  foreach($a as $proto){

    if (array_search($proto->sender, $regex) !== false ) {
      $ip = $proto->bytes;
      $size = $proto->bytes;
    }
  }

  if (!empty($output)){
    	$output = 'No data found.';
  }

  if ($np->opts['unity'] === kb ){
      $size = $size / 1024;
      $size = round($size, 2);
      $unity = $size."KB";
  } elseif ($np->opts['unity'] === mb ){
      $size = $size / 1024 / 1024;
      $size = round($size, 2);
      $unity = $size."MB";
  } else {
    print "Unity not supported";
  }

  $warning = $np->opts['warning'];
  $critical = $np->opts['critical'];
  $code = metric ($size, $warning, $critical);

  $metric = strtoupper($np->opts['unity']);

  $perfdata = "traffic=".$unity.";".$warning.";".$critical.";0;";

  $output = "Traffic from ".$np->opts['ip']." is ".$size.$metric;

  print $output." | ".$perfdata."\n";

  exit($code);

}
main ();
