#!/usr/bin/php -q
<?php
include "/usr/local/opmon/etc/config.php";

class OpmonObjectsMgr {

	public $fruity = null;

	public function __construct()
	{
		$config_manager = new ConfigManager();
		$this->fruity = $config_manager->cfg;
	}

	public function add_host($host_template_name, $host_name, $address)
	{
		$host_id = $this->fruity->return_host_id_by_name($host_name);
		if ($host_id) {
			return $host_id;
		}
		$host = array('host_name' => $host_name, 'alias' => $host_name,'address'=>$address);
		$template_id = $this->fruity->return_host_template_id_by_name($host_template_name);
		if (!$template_id) {
			die("invalid host template name ($host_template_name)\n");
		}
		$host['use_template_id'] = $template_id;
		$this->fruity->add_host($host);
		$host_id = $this->fruity->return_host_id_by_name($host_name);
		return $host_id;
	}

	public function add_service($service_template_name, $service_description, $host_id)
	{
		$service_id = $this->fruity->return_service_id_by_host_and_description($host_id, $service_description);
		if ($service_id) {
			return $service_id;
		}
		$service = array('service_description' => $service_description,'host_id' => $host_id);
		$template_id = $this->fruity->return_service_template_id_by_name($service_template_name);

		if (!$template_id) {
			die("invalid service template name ($service_template_name)\n");
		}
		$service['use_template_id'] = $template_id;
		$this->fruity->add_service($service);
		$service_id = $this->fruity->return_service_id_by_host_and_description($host_id, $service_description);
		return $service_id;
	}

	public function add_hostgroup($hostgroup_name)
	{
		$hostgroup_id = $this->fruity->return_hostgroup_id_by_name($hostgroup_name);
		if ($hostgroup_id) {
			return $hostgroup_id;
		}
		$this->fruity->add_hostgroup_with_map(array('hostgroup_name' => $hostgroup_name,'alias'=>$hostgroup_name));
		$hostgroup_id = $this->fruity->return_hostgroup_id_by_name($hostgroup_name);
		return $hostgroup_id;
	}

	public function add_hostgroup_member($hostgroup_id, $host_id)
	{
		$this->fruity->add_hostgroup_member($hostgroup_id, $host_id);
	}

	public function add_servicegroup($servicegroup_name)
	{
		$servicegroup_id = $this->fruity->return_servicegroup_id_by_name($servicegroup_name);
		if ($servicegroup_id) {
			return $servicegroup_id;
		}
		$this->fruity->add_servicegroup_with_map(
			array(
				'servicegroup_name' => $servicegroup_name,
				'alias' => $servicegroup_name
			)
		);
		$servicegroup_id = $this->fruity->return_servicegroup_id_by_name($servicegroup_name);
		return $servicegroup_id;
	}

	public function add_servicegroup_member($service_id, $servicegroup_id)
	{
		$this->fruity->add_service_servicegroup($service_id, $servicegroup_id);
	}

	public function add_host_template($template_name, $base_template_name, $command_name, $check_interval)
	{
		$template_id = $this->fruity->return_host_template_id_by_name($template_name);
		if ($template_id) {
			return $template_id;
		}
		$base_template_id = $this->fruity->return_host_template_id_by_name($base_template_name);
		if (!$base_template_id) {
			die("Invalid host base_template_name\n");
		}
		$base_template = array();
		$this->fruity->get_host_template_info($base_template_id, $base_template);
		unset($base_template['host_template_id']);

		$command_info = $this->fruity->get_command_by_name($command_name);
		if (!$command_info) {
			$command = array(
				'command_name' => $command_name,
				'command_line' => '$USER1$/opservices/dummy/check_ini_dummy -H "$HOSTNAME$"',
				'command_desc' => $command_name,
				'system' => 0,
				'command_type' => 1
			);
			$this->fruity->add_command($command);
			$command_info = $this->fruity->get_command_by_name($command_name);
		}

		$base_template['template_name'] = $template_name;
		$base_template['template_description'] = $template_name;
		$base_template['check_command'] = $command_info['command_id'];
		$base_template['check_interval'] = $check_interval;

		foreach (array(
			'passive_checks_enabled',
			'obsess_over_host',
			'check_freshness',
			'checks_enabled',
			'event_handler',
			'event_handler_enabled',
			'failure_prediction_enabled') as $p) {
			unset($base_template[$p]);
		}


		$this->fruity->add_host_template($base_template);
		$template_id = $this->fruity->return_host_template_id_by_name($template_name);

		$this->fruity->add_host_template_contactgroup($template_id, 1);

		return $template_id;
	}

	public function add_service_template($template_name, $base_template_name, $command_name, $check_interval)
	{
		$template_id = $this->fruity->return_service_template_id_by_name($template_name);
		if ($template_id) {
			return $template_id;
		}

		$base_template_id = $this->fruity->return_service_template_id_by_name($base_template_name);
		if (!$base_template_id) {
			die("Invalid service base_template_name\n");
		}
		$base_template = array();
		$this->fruity->get_service_template_info($base_template_id, $base_template);

		foreach (array(
			'service_template_id',
			'is_volatile',
			'event_handler',
			'check_freshness',
			'event_handler_enabled',
			'stalking_options_ok',
			'stalking_options_warning',
			'stalking_options_unknown',
			'stalking_options_critical',
			'failure_prediction_enabled',
			'baseline_seasonality') as $p) {
			unset($base_template[$p]);
		}

		$command_info = $this->fruity->get_command_by_name($command_name);
		if (!$command_info) {
			$command = array(
				'command_name' => $command_name,
				'command_line' => '$USER1$/opservices/dummy/check_ini_dummy -H "$HOSTNAME$" -S "$SERVICEDESC$"',
				'command_desc' => $command_name,
				'system' => 0,
				'command_type' => 1
			);
			$this->fruity->add_command($command);
			$command_info = $this->fruity->get_command_by_name($command_name);
		}
		$base_template['template_name'] = $template_name;
		$base_template['template_description'] = $template_name;
		$base_template['check_command'] = $command_info['command_id'];
		$base_template['normal_check_interval'] = $check_interval;


		$this->fruity->add_service_template($base_template);
		$template_id = $this->fruity->return_service_template_id_by_name($template_name);
		return $template_id;
	}
}

function get_ini($file)
{

	if (!$file) {
		$file = '/usr/local/opmon/libexec/opservices/dummy/init_dummy.ini';
	}

	if (file_exists($file)) {
		$ini = file($file);
	} else {
		print 'Cant find '.$file."\n";
		exit(CRITICAL);
	}

	return $ini;
}

function get_options()
{

	$options = getopt("H:f:");

	if (!count($options)) {
		print "Use -H qtd host";
		exit;
	}

	return $options;
}

function main()
{

	$options = get_options();
	$ini = get_ini($options['f']);
	$qtd = $options['H'];

	$lic = get_opmon_license_properties();
	if (preg_match("/10\s\/.+/", $lic[3]->content)) {
		print "Need new license for more hosts and service unlimited.\n";
		exit;
	}

	$host_template = 'generic-host-dummy';
	$base_host_template = 'generic-host';

	$service_template = 'generic-service-dummy';
	$base_service_template = 'generic-service';

	$check_dummy_cmd = 'check_ini_dummy';
	$check_dummy_path = '/usr/local/opmon/libexec/opservices/dummy';

	$host_command = 'check_dummy_host';
	$service_command = 'check_dummy_service';

	$host_address = '127.0.0.1';

	$host_check_interval = 5;
	$service_check_interval = 5;

	$export_info = '/var/local/opmon/utils/opmon-export.php';

	$mgr = new OpmonObjectsMgr();

	print "adding host template: $host_template\n";
	$mgr->add_host_template($host_template, $base_host_template, $host_command, $host_check_interval);

	print "adding service template: $service_template\n";
	$mgr->add_service_template($service_template, $base_service_template, $service_command, $service_check_interval);

	print "Validating lines in ini file\n";
	foreach ($ini as $line) {
		$array = explode('|', $line);

		if ((count($array) == 5) or (count($array) == 4)) {
			print "Format line OK\n";
		} else {
			print "Invalid format ini file. Line: \n$line\n";
			exit;
		}
	}

	foreach ($ini as $line) {
		$array = explode('|', $line);

		$host = null;
		$service = null;
		$group = null;
		$output = null;
		$metrics = null;

		if (count($array) == 5) {
			list($host, $service, $group, $output, $metrics) = explode('|', $line);
		} else {
			list($host, $group, $output, $metrics) = explode('|', $line);
		}

		if (isset($host) and $service == null) {
			print "Hostgroup: $group\n";
			$hostgroup_id = $mgr->add_hostgroup($group);

			$hosts = array();

			for ($i=1; $i<=$qtd; $i++) {
				$hostname = $host."_".$i;
				print "Host: $host\n";
				$host_id = $mgr->add_host($host_template, $hostname, $host_address);
				print "Host ID: $host_id\n";
				$mgr->add_hostgroup_member($hostgroup_id, $host_id);
				$hosts[] = $host_id;
			}

		} elseif (isset($host) and isset($service)) {
			print "Servicegroup: $group\n";
			$servicegroup_id = $mgr->add_servicegroup($group);

			foreach ($hosts as $id) {
				print "Host $host Service: $service\n";
				$service_id = $mgr->add_service($service_template, $service, $id);
				print "Host ID: $id Service ID: $service_id\n";
				$mgr->add_servicegroup_member($service_id, $servicegroup_id);
			}
		}
	}

	print "Running export\n";
	exec($export_info);
	sleep(3);
	print "Done. Waiting export...\n";
}

main();
