#!/usr/bin/php
<?php
include "/usr/local/opmon/etc/config.php";
$mod = "EXTERNAL";
set_logged_user("opmonadmin");

// global stuff
define("_VERSION",0.05);


$valid_periods = array(
            "lasthour",
            "today",
            "last24hours",
            "thisweek",
            "last7days",
            "thismonth",
            "last31days",
            "thisyear",
            "thishour"
);

function main() {

    global $valid_periods;
    $options = getopt("Ssvhmt:o:w:c:p:T:");

    if (isset($options['v'])) {
        usage(true);
        return UNKNOWN;
    }

    if (isset($options['h'])) {
        usage();
        return UNKNOWN;
    }

    if ( !isset($options['t']) ||
         !isset($options['o']) ) {
        usage();
        return UNKNOWN;
    }

    $tcname = "24x7";
    if (isset($options['T'])) {
        $tcname = $options['T'];
    }

    $tc = get_timecut_by_name($tcname);
    if ($tc === false) {
        print "Unable to locate timecut $tcname\n";
        return UNKNOWN;
    }

    $objects = get_objects($options['t'],$options['o']);

    if (empty($objects)) {
        print "Unable to locate object {$options['o']}. Please verify type(-t) and description(-o)\n";
        return UNKNOWN;
    }

    $period = "last7days";
    if (isset($options['p'])) {
        $period = $options['p'];
    }

    if (array_search($period,$valid_periods) === false) {
        print "Unknown/invalid period {$options['p']}\n";
        return UNKNOWN;
    }

    //list($from,$to) = get_time_stamps($period);

    $time_ok = 0;
    $time_warning = 0;
    $time_critical = 0;
    $time_unknown = 0;

    $ok = 0;
    $warning = 0;
    $critical = 0;
    $unknown = 0;
    $max_ok = false;
    foreach($objects as $obj) {

        if (get_class($obj) !== 'Scat') {
            $obj->get_avail_instance();

            if (isset($options['s'])) {
                $obj->avail->setSchedAsOk();
            }

            if (isset($options['S'])) {
                $obj->avail->setSoftState();
            }

            $obj->avail->setPeriod($period);
            $obj->avail->setTimeCutId($tc->id);
            $obj->avail->calcule();

            $time_ok += $obj->avail->timeOk;
            $time_warning += $obj->avail->timeWarning;
            $time_unknown += $obj->avail->timeUnknown;
            $time_critical += $obj->avail->timeCritical;

            $ok += $obj->avail->timePctOk;
            $warning += $obj->avail->timePctWarning;
            $critical += $obj->avail->timePctCritical;
            $unknown += $obj->avail->timePctUnknown;

            if ($obj->avail->maxTimePctOk !== false) {
                $max_ok += $obj->avail->maxTimePctOk;
            }

        } else {

            if (isset($options['s'])) {
                $obj->set_sched_as_ok();
            }

            if (isset($options['S'])) {
                $obj->set_soft_states();
            }

            $obj->set_period($period);
            $obj->set_timecut_id($tc->id);
            $obj->calcule();

            $ok += $obj->time_pct_ok;
            $critical += $obj->time_pct_critical;

            $time_ok += $obj->time_ok;
            $time_critical += $obj->time_critical;

            if ($obj->max_time_pct_ok !== false) {
                $max_ok += $obj->max_time_pct_ok;
            }
        }

        unset($obj->avail);

    }


    $count = count($objects);
    if ($count == 0)
        $count = 1;

    $time_ok = sprintf("%.1f", ($time_ok/$count) / 60 );
    $time_warning = sprintf("%.1f", ($time_warning/$count) / 60 );
    $time_critical = sprintf("%.1f", ($time_critical/$count) / 60);
    $time_unknown = sprintf("%.1f", ($time_unknown/$count) / 60 );

    $ok = sprintf("%.3f",$ok / $count);
    $warning = sprintf("%.3f",$warning / $count);
    $critical = sprintf("%.3f",$critical / $count);
    $unknown = sprintf("%.3f",$unknown / $count);
    if ($max_ok !== false) {
        $max_ok = sprintf("%.3f",$max_ok / $count);
    }

    $exit_code = OK;
    if ($ok < $options['c']) {
        $exit_code = CRITICAL;
    } else if ($ok < $options['w']) {
        $exit_code = WARNING;
    }


    // OUTPUT FORMAT
    print $options['o'].": ";
    if ($options['t'] == 'IC' || $options['t'] == 'ICG') {

        print "UP: $ok% DOWN: $critical% UNREACHABLE: $unknown% |";
        print "up=$ok;{$options['w']};{$options['c']};0;100 ";
        print "down=$critical;;;0;100 ";
        print "unreachable=$unknown;;;0;100";

        if (isset($options['m'])) {

            print " minutes_up=$time_ok;;;;";
            print " minutes_down=$time_critical;;;;";
            print " minutes_unreachable=$time_unknown;;;;";

        }

        if ($max_ok !== false) {
            print " max_up=$max_ok;;;0;100";
        }

    } else if ($options['t'] == 'AIC' || $options['t'] == 'AICG') {
        print "OK: $ok% WARNING: $warning% CRITICAL: $critical% UNKNOWN: $unknown% |";
        print "ok=$ok;{$options['w']};{$options['c']};0;100 ";
        print "warning=$warning;;;0;100 ";
        print "critical=$critical;;;0;100  ";
        print "unknown=$unknown;;;0;100";

        if (isset($options['m'])) {

            print " minutes_ok=$time_ok;;;;";
            print " minutes_warning=$time_warning;;;;";
            print " minutes_critical=$time_critical;;;;";
            print " minutes_unknown=$time_unknown;;;;";

        }

        if ($max_ok !== false) {
            print " max_ok=$max_ok;;;0;100";
        }

    } else {

        print "OK: $ok% CRITICAL: $critical% |";
        print "ok=$ok;{$options['w']};{$options['c']};0;100 ";
        print "critical=$critical;;;0;100 ";

        if (isset($options['m'])) {

            print " minutes_ok=$time_ok;;;;";
            print " minutes_critical=$time_critical;;;;";

        }

        if ($max_ok !== false) {
            print " max_ok=$max_ok;;;0;100";
        }

    }

    print "\n";

    return $exit_code;

}

function get_objects($type,$object) {

    $objects = array();
    switch($type) {

    // host
    case 'IC':
        $host = get_host_by_name($object);

        if ($host === false)
            break;

        $objects[] = $host;
        break;

    // service
    case 'AIC':
        list($hname,$sdescr) = explode(":",$object);

        $host = get_host_by_name($hname);
        if ($host !== false) {

            $services = $host->get_services();
            foreach($services as $svc) {
                if ($svc->get_service_description() == $sdescr) {
                    $objects[] = $svc;
                }
            }
        }
        break;

    // hostgroup
    case "ICG":
        $hgs = get_hostgroups();
        if (is_array($hgs)) {
            foreach($hgs as $hg) {
                if ($hg->hostgroup_name == $object) {
                    $host = get_host($hg->host_id);
                    if ($host !== false) {
                        $objects[] = $host;
                    }
                }
            }
        }
        break;

    // servicegroup
    case "AICG":
        $sgs = get_servicegroups();
        if (is_array($sgs)) {
            foreach($sgs as $sg) {
                if ($sg->servicegroup_name == $object) {
                    $svc = get_service_by_id($sg->host_id,$sg->service_id);
                    if ($svc !== false) {
                        $objects[] = $svc;
                    }
                }
            }
        }
        break;

    // servicecatalogs
    case "SCAT":
        $scat = get_scat_by_name($object);
        if ($scat !== false) {
            $objects[] = $scat;
        }
        break;

    }

    return $objects;


}

function usage($only_version = false) {
    global $valid_periods;

    print "getavail.php v."._VERSION."\n";
    if ($only_version)
        return;

    print "\nUsage:\n";
    print "getavail.php [-v] [-h] -t <type> -p <period> -o <object> -w <warning> -c <critical> [-p <period>] [-T <timecut name>] [-m] [-s] [-S]\n";
    print "\n";
    print "Options:\n";
    print "-v\n";
    print "\tPrints agent version\n";
    print "-h\n";
    print "\tPrints this help message\n";
    print "-t <type>\n";
    print "\tObject type, it should be: IC(Host),AIC(Service),ICG(HostGroup),AICG(ServiceGroup) or SCAT(Service Catalog)\n";
    print "-o <object>\n";
    print "\tObject description, for service use host_name:service_description\n";
    print "-w <warning>\n";
    print "\tWarning threshold(if the availability is below this limit, a warning alert will be generated\n";
    print "-c <critical>\n";
    print "\tCritical threshold(if the availability is below this limit, a critical alert will be generated\n";
    print "-p <period>\n";
    print "\tAvail time period. It must be: ".implode(", ",$valid_periods)."\n";
    print "\tDefault value points to last7days\n";
    print "-T <timecut name>\n";
    print "\tUse this option to specify a timecut different from '24x7'\n";
    print "-m \n";
    print "\tCreate a new metric to present the time in minutes per state\n";
    print "-s \n";
    print "\tConsider scheduled downtimes periods as OK\n";
    print "\n";
    print "-S \n";
    print "\tUse soft states\n";
    print "\n";
    print "Examples:\n";
    print "\tgetavail.php -t IC -o 'hostX' -p thisyear\n";
    print "\t\tCalcule the availability for hostX host this year\n\n";
    print "\tgetavail.php -t AIC -o 'hostX:serviceY' -p last7days -T '8x5'\n";
    print "\t\tCalcule the availability for serviceY service on hostX host for the last 7 days using timecut 8x5\n\n";
    print "\tgetavail.php -t IC -o 'hostX' -p today -w 79 -c 75\n";
    print "\t\tCalcule the availability for hostX host today. Generates critical alert if availability < 75% and\n";
    print "\t\twarning alert if availiability > 75% and < 79%\n";



    print "\n";
}

exit(main());

?>
