#!/usr/bin/perl
#notify_by_opalert
#Description:
#       OpMon Notification via OpAlert
#Author:
#	Estevan Ramalho (estevan.ramalho@opservices.com.br)
#Version:
#	1.0 18-07-2013: Initial release

use strict;
use Getopt::Long;
use POSIX;

$ENV{"USER"}="opuser";
$ENV{"HOME"}="/home/opuser";

our $version = "1.0";
our $name = "notify_by_opalert";
our $path = "/usr/local/opmon/libexec/opservices/";

our ($opt_version, $opt_help, $opt_debug, $opt_user, $opt_pass, $opt_from, $opt_to, $opt_detail, $opt_env);
our ($opt_date, $opt_Ntype, $opt_Hname, $opt_Haddr, $opt_Hstate, $opt_Sname, $opt_Sstate);

our $usage ='
Usage: '. $0 .' [OPTION]...
Send a SMS notification via OpAlert system, for hosts and services.

General Options:
        -e, --env		Get data from environmental variables (service|host|test)
        -t, --to		Recipient number		

Extra Options:

        -h, --help              Display this help and exit
        -v, --version           Output version information and exit
        -d, --debug     	1 = Debug
                        	2 = Generate log file

Send email to suporte@opservices.com.br if you have questions
regarding use of this software. To submit patches or suggest improvements,
send email to suporte@opservices.com.br.
Please include version information with all correspondence (when possible,
use output from the --version option of the plugin itself).

';

sub main {
        # Get options
        getOptions();
	logger($opt_debug, "----- Starting -----");
	# Get the OpMon Environmental Variables
	get_env();
	logger($opt_debug, "----- Environmental Variables -----");
	logger($opt_debug, $opt_Ntype); 
        logger($opt_debug, $opt_date);
        logger($opt_debug, $opt_Hname);
	# Get the Ticket Description
	my $msg = get_msg();
	logger($opt_debug, "Message:\n$msg");
	# Send Message
	logger($opt_debug, "----- Send Message -----");
	my $return = send_msg($msg);
	logger($opt_debug, "OK - The message has been sent");
	exit (0);
}

sub send_msg {
	my $msg = shift;
	my $sms_msg = "From: OpAlert\nTo: 55$opt_to\n\n$msg\n";
	my $sms_msg_file =  "/var/spool/sms/outgoing/opalert.$$";
	logger($opt_debug,"FILE: $sms_msg_file");
	logger($opt_debug,"MESSAGE:\n$sms_msg");
	open(SMS,">$sms_msg_file");
	print SMS $sms_msg;
	close(SMS);
	return(0);
} 

sub getOptions { 
        Getopt::Long::Configure('bundling');
        GetOptions(
                'v|version'     => \$opt_version,
                'h|help'        => \$opt_help,
                'd|debug=i'     => \$opt_debug,
                'e|env=s'       => \$opt_env,
                't|to=s'	=> \$opt_to,
        ); 

        if ($opt_version) { print $name." ".$version."\n"; exit(0); }
        if ($opt_help){ print $usage; exit(0); }
	if ((!$opt_to) || ($opt_env !~ /host|service|test/)){ print $usage; exit(3); } 
        if ( ($opt_debug) and ($opt_debug !~ /1|2/ ) ){ usage("Option Missing:\t-d|--debug\t(1|2)\n"); }
}

sub get_env {
        logger($opt_debug,"Loading Environmental Variables");
	if ($opt_env =~ /test/){
	        $opt_Ntype  = "NAGIOS_NOTIFICATIONTYPE";
	        $opt_date   = "NAGIOS_SHORTDATETIME";
	        $opt_Hname  = "NAGIOS_HOSTNAME";
	        $opt_Haddr  = "NAGIOS_HOSTADDRESS";
                $opt_Hstate = "NAGIOS_HOSTSTATE";
                $opt_Sname  = "NAGIOS_SERVICEDESC";
                $opt_Sstate = "NAGIOS_SERVICESTATE";
		$opt_detail = "NAGIOS_SERVICEOUTPUT";
	} else {
        	$opt_Ntype = $ENV{'NAGIOS_NOTIFICATIONTYPE'};
        	$opt_date  = $ENV{'NAGIOS_SHORTDATETIME'};
        	$opt_Hname = $ENV{'NAGIOS_HOSTNAME'};
        	if ($opt_env =~ /host/){
        		$opt_Haddr  = $ENV{'NAGIOS_HOSTADDRESS'};
        	        $opt_Hstate = $ENV{'NAGIOS_HOSTSTATE'};
        	}else{
        	        $opt_Sname  = $ENV{'NAGIOS_SERVICEDESC'};
        	        $opt_Sstate = $ENV{'NAGIOS_SERVICESTATE'};
			$opt_detail = $ENV{'NAGIOS_SERVICEOUTPUT'};
        	}
	}
        return;
}

sub get_msg {
	my $msg;
	if ($opt_env =~ /host/){ 
		$msg = "$opt_Ntype\nHost: $opt_Hname\nState: $opt_Hstate\nAddress: $opt_Haddr\nDate/Time: $opt_date"; 
	} elsif ($opt_env =~ /service/) { 
		$msg = "$opt_Ntype\nHost: $opt_Hname\nService: $opt_Sname\nState: $opt_Sstate\nDetail: $opt_detail\nDate/Time: $opt_date"; 
	} else { 
		$msg = "$opt_Ntype\nHost: $opt_Hname\nService: $opt_Sname\nState: $opt_Sstate\nDetail: $opt_detail\nDate/Time: $opt_date"; 
	}
	return($msg);
}

sub logger {
        my $opt = shift;
        my $msg = shift;
        my $log = "$path/$name.log";
        my $date = strftime("%d/%m/%Y - %H:%M:%S",localtime);
        if ($opt == 1){ print "$msg\n"; }
	elsif ($opt == 2) {
		open(LOG, ">>$log");
		print LOG "$date => $msg\n";
		close(LOG);
        }
}

&main;
