#!/usr/bin/php
<?php

require_once '/usr/local/opmon/etc/config.php';
require_once '/usr/local/opmon/libexec/php-nagios-plugins/Nagios_Plugin.php';

define("VERSION", "3.1");
define("TELNET_PORT", 23);

$np = null;

/*******************************************************************************
* Exibir o manual do software
********************************************************************************/
function getGuideLine()
{

    $name = basename(__FILE__);
    $realpath = realpath(__FILE__);
    print <<<EOF

------------------------------------------
Manual de exemplo.
------------------------------------------

Descrição do plugin:
    Executa o backup de switchs e armazena um arquivo com os dados no
    OpMon utilizando OpSCM (OpMon Source Configuration Manager).

Instalação:
    Copiar este plugin para a pasta de plugins no path abaixo:
    /usr/local/opmon/libexec/opservices.

    Dar permissão de execução( chmod +x $realpath )

Dependências:
    Nagios_Plugins para php

Funcionamento:
    Obtem as configurações de switchs executando commandos através do telnet.

    Após o obter a configuração o plugin irá armazenar os dados no OpMon
    para possibilitar o controle de versão do mesmo.

Exemplos de execução:
    ./$name -H <nome do host no opmon> -i <credential id> -m <switch model> -v
    [modo verbose]

    ./$name -H <nome do host no opmon> -i <credential id> -m <switch model>
    [Obtem as configurações do switch (default)]


EOF;

    exit(OK);

}

/*******************************************************************************
* Seta os atributos da variável global $np
********************************************************************************/
function setNagios()
{

    # Constructor
    global $np;

    $np = new Nagios_Plugin(
        array (
            'version' => VERSION . " [www.opservices.com.br/suporte]",
            'blurb' => "Developed by:\n\tOpServices\n"
            . "Author: \n\tSidney Souza - sidney.souza@opservices.com.br\n",
            'usage' => "Usage:\n\t%s -H <host name> -i <credential-id> -m <model>\n"
            . " \t [-p <telnet port>] [-I] [-v] [--man] [-h] [-?] [-c <command>]",
        )
    );

    $np->add_arg("hostname|H=s", "Name of host in OpMon");
    $np->add_arg("port|p=i", "Telnet port to connect");
    $np->add_arg("credential-id|i=i", "Credential id");
    $np->add_arg("m|model=s", "Switch model, It's can be (dlink|3com|cisco)");
    $np->add_arg("man", "Show guideline");
    $np->add_arg("run", "Run backup in background");
    $np->add_arg("c|backup-command=s", "Custom command that will be used to perform backup");
    $np->add_arg("s|service-description=s", "Custom service_description");

    $np->getopts();

}

function sendPassiveResult($status, $output)
{
    global $np;

    Cmd::serviceSendPassiveCheckResult(array(
        'time' => time(),
        'host_name' => $np->opts['hostname'],
        'service_description' => $np->opts['service-description'],
        'check_result' => $status,
        'plugin_output' => $output
    ));
}

/*******************************************************************************
* Executa os comandos necessários no equipamento para obter a configuração
*
* @return String $configuration Configurações obtidas do telnet.
********************************************************************************/
function getConfiguration()
{
    global $np;

    $connector = new TelnetConnector();

    if (isset($np->opts['verbose'])) {
        $connector->set_verbose();
    }

    try {
        $connector->open($np->opts['host_address']);
    } catch (TelnetConnectorException $e) {
        sendPassiveResult(CRITICAL, $e->getMessage());
    }

    try {
        $configuration = executeCommandsSwitch($connector);
    } catch (TelnetConnectorException $e) {
        sendPassiveResult(CRITICAL, $e->getMessage());
    } catch (InvalidArgumentException $e) {
        sendPassiveResult(UNKNOWN, $e->getMessage());
    }

    $connector->close();

    return removeTrashFromConfiguration($configuration);
}

function removeTrashFromConfiguration($configuration)
{
    global $np;

    $configuration = preg_replace(
        '/.*' . $np->opts['backup-command']. '/s',
        '',
        $configuration
    );

    return trim(preg_replace(
        '/' . $np->opts['hostname'] . '(\s+)?#/',
        '',
        $configuration
    ));
}

function executeCommandsSwitch(&$connector)
{
    global $np;

    $credential = new UserCredentials();

    $credential->retrieve($np->opts['credential-id']);

    if ($np->opts['model'] == '3com') {
        $connector->set_timeout(10);

        try {
            $connector->execute('/username:/i', $credential->get_username())
                ->execute('/password:/i', $credential->get_password())
                ->execute('/login/i', '')
                ->execute('/>/', "\n");
        } catch (Exception $e) {
            sendPassiveResult(CRITICAL, 'Login failed');
            exit(CRITICAL);
        }

        $connector->set_timeout(500)->clear_buffer();

        $connector->execute('/>/', $np->opts['backup-command'])
               ->execute('/return/i', 'quit');

        return $connector->get_buffer();
    }

    if ($np->opts['model'] == 'dlink') {
        $connector->execute('/username:/i', $credential->get_username())
               ->execute('/password:/i', $credential->get_password());

        $connector->set_timeout(500);

        $connector->execute('/:4#/', $np->opts['backup-command'])
               ->clear_buffer()
               ->execute('/All/', 'a')
               ->execute('/:4#/', 'logout');

        return $connector->get_buffer();
    }

    if ($np->opts['model'] == 'cisco') {
        $connector->execute('/username:/i', $credential->get_username())
               ->execute('/password:/i', $credential->get_password())
               ->execute('/#/', 'terminal length 0')
               ->execute('/#/', $np->opts['backup-command'])
               ->execute('/^end$/', '') //End of configuration
               ->execute('/#/', 'logout');

        return $connector->get_buffer();
    }

    quit("Model not implemented yet");
}

function quit($msg, $status = UNKNOWN)
{
    global $np;
    sendPassiveResult($status, $msg);
    $np->nagios_die($msg);
}

/*******************************************************************************
* Envia as informações passadas por parametro para o servidor OpSCM no OpMon
********************************************************************************/
function store($data)
{
    global $np;

    if (empty($data)) {
        $np->nagios_die("Invalid file content");
    }

    $scm = new Scm();
    $out = new StdClass();

    $scm->set_host_id($np->opts['host_id']);
    $scm->set_name('switch.cfg');
    $scm->set_content(base64_encode($data));
    $scm->set_md5_content(md5($data));

    $out->status = OK;
    $out->output = "Configuration file has no changes since last update";

    // the file change since the last commit
    if ($scm->store() !== false) {
        $out->status = CRITICAL;
        $out->output = "The configuration file has changes)";
    }

    unset($scm);

    return $out;
}

function getHostInformation()
{
    global $np;

    $host = get_host_by_name($np->opts['hostname']);
    if (! $host instanceof Host) {
        $np->nagios_exit(CRITICAL, "Host not found");
    }

    $np->opts['host_address'] = $host->get_address();
    $np->opts['host_id'] = $host->get_host_id();
}

/*******************************************************************************
* Rotina principal do programa
********************************************************************************/

function main()
{
    setNagios();

    global $np;

    $commands = array(
        '3com' => 'display current-configuration configuration',
        'dlink' => 'show config current_config',
        'cisco' => 'show running-config',
    );

    if (isset($np->opts['man'])) {
        getGuideLine();
    }

    if (! isset($np->opts['hostname'])) {
        $np->nagios_die("Hostname is required");
    }

    if (! isset($np->opts['credential-id'])) {
        $np->nagios_die("Credential ID is required");
    }

    if (! isset($np->opts['model'])) {
        $np->nagios_die("Switch model is required");
    }

    if (! preg_match('/^(cisco|3com|d-?link)$/i', $np->opts['model'])) {
        $np->nagios_die("Switch model is not support");
    }

    $np->opts['model'] = strtolower($np->opts['model']);
    $np->opts['model'] = str_replace('-', '', $np->opts['model']);

    $np->opts['backup-command']
        = $np->opts['backup-command'] ?: $commands[ $np->opts['model'] ];

    $np->opts['service-description']
        = $np->opts['service-description'] ?: 'Configuration_Backup';

    $np->opts['port'] = $np->opts['port'] ?: TELNET_PORT;

    getHostInformation();

    if (! isset($np->opts['run'])) {
        $command = sprintf(
            '%s -H %s -i %d -m %s -p %d -s %s --run > /dev/null 2>/dev/null &',
            realpath(__FILE__),
            $np->opts['hostname'],
            $np->opts['credential-id'],
            $np->opts['model'],
            $np->opts['port'],
            $np->opts['service-description']
        );

        shell_exec($command);
        $np->nagios_exit(OK, 'Starting backup...');
    }

    $configuration = getConfiguration();
    $response = store($configuration);
    sendPassiveResult($response->status, $response->output);
    exit(OK);
}

main();
# vim: set smartindent tabstop=4 shiftwidth=4 softtabstop=4 expandtab
